import typing

import android.content
import android.graphics
import android.graphics.drawable
import android.graphics.text
import android.icu.util
import android.os
import android.util
import android.view
import java
import java.chaquopy
import java.lang
import java.util
import java.util.regex
import org.xml.sax

class AlteredCharSequence(GetChars, java.lang.CharSequence):
    def charAt(self, off: int | java.jint | java.lang.Integer, /) -> str: ...
    def getChars(self, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, dest: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, /) -> None: ...
    def length(self) -> int: ...
    @staticmethod
    def make(source: java.lang.CharSequence, sub: java.chaquopy.JavaArrayJChar, substart: int | java.jint | java.lang.Integer, subend: int | java.jint | java.lang.Integer, /) -> AlteredCharSequence: ...
    def subSequence(self, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> java.lang.CharSequence: ...
    def toString(self) -> str: ...

class AndroidCharacter(java.lang.Object):
    EAST_ASIAN_WIDTH_AMBIGUOUS: typing.ClassVar[int] = ...
    EAST_ASIAN_WIDTH_FULL_WIDTH: typing.ClassVar[int] = ...
    EAST_ASIAN_WIDTH_HALF_WIDTH: typing.ClassVar[int] = ...
    EAST_ASIAN_WIDTH_NARROW: typing.ClassVar[int] = ...
    EAST_ASIAN_WIDTH_NEUTRAL: typing.ClassVar[int] = ...
    EAST_ASIAN_WIDTH_WIDE: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    @staticmethod
    def getDirectionalities(arg1: java.chaquopy.JavaArrayJChar, arg2: java.chaquopy.JavaArrayJByte, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def getEastAsianWidth(arg1: str | java.jchar | java.lang.Character, /) -> int: ...
    @staticmethod
    def getEastAsianWidths(arg1: java.chaquopy.JavaArrayJChar, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: java.chaquopy.JavaArrayJByte, /) -> None: ...
    @staticmethod
    def getMirror(arg1: str | java.jchar | java.lang.Character, /) -> str: ...
    @staticmethod
    def mirror(arg1: java.chaquopy.JavaArrayJChar, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> bool: ...

class Annotation(ParcelableSpan):
    @typing.overload
    def __init__(self, src: android.os.Parcel, /) -> None: ...
    @typing.overload
    def __init__(self, key: str | java.lang.String, value: str | java.lang.String, /) -> None: ...
    def describeContents(self) -> int: ...
    def getKey(self) -> str: ...
    def getSpanTypeId(self) -> int: ...
    def getValue(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class AutoText(java.lang.Object):
    @staticmethod
    def get(src: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, view: android.view.View, /) -> str: ...
    @staticmethod
    def getSize(view: android.view.View, /) -> int: ...

class BidiFormatter(java.lang.Object):
    @typing.overload
    @staticmethod
    def getInstance() -> BidiFormatter: ...
    @typing.overload
    @staticmethod
    def getInstance(locale: java.util.Locale, /) -> BidiFormatter: ...
    @typing.overload
    @staticmethod
    def getInstance(rtlContext: bool | java.jboolean | java.lang.Boolean, /) -> BidiFormatter: ...
    def getStereoReset(self) -> bool: ...
    @typing.overload
    def isRtl(self, str: java.lang.CharSequence, /) -> bool: ...
    @typing.overload
    def isRtl(self, str: str | java.lang.String, /) -> bool: ...
    def isRtlContext(self) -> bool: ...
    @typing.overload
    def unicodeWrap(self, str: java.lang.CharSequence, /) -> java.lang.CharSequence | None: ...
    @typing.overload
    def unicodeWrap(self, str: str | java.lang.String, /) -> str | None: ...
    @typing.overload
    def unicodeWrap(self, str: java.lang.CharSequence, heuristic: TextDirectionHeuristic, /) -> java.lang.CharSequence | None: ...
    @typing.overload
    def unicodeWrap(self, str: java.lang.CharSequence, isolate: bool | java.jboolean | java.lang.Boolean, /) -> java.lang.CharSequence | None: ...
    @typing.overload
    def unicodeWrap(self, str: str | java.lang.String, heuristic: TextDirectionHeuristic, /) -> str | None: ...
    @typing.overload
    def unicodeWrap(self, str: str | java.lang.String, isolate: bool | java.jboolean | java.lang.Boolean, /) -> str | None: ...
    @typing.overload
    def unicodeWrap(self, str: java.lang.CharSequence, heuristic: TextDirectionHeuristic, isolate: bool | java.jboolean | java.lang.Boolean, /) -> java.lang.CharSequence | None: ...
    @typing.overload
    def unicodeWrap(self, str: str | java.lang.String, heuristic: TextDirectionHeuristic, isolate: bool | java.jboolean | java.lang.Boolean, /) -> str | None: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, locale: java.util.Locale, /) -> None: ...
        @typing.overload
        def __init__(self, rtlContext: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def build(self) -> BidiFormatter: ...
        def setTextDirectionHeuristic(self, heuristic: TextDirectionHeuristic, /) -> BidiFormatter.Builder: ...
        def stereoReset(self, stereoReset: bool | java.jboolean | java.lang.Boolean, /) -> BidiFormatter.Builder: ...

class BoringLayout(Layout, TextUtils.EllipsizeCallback):
    @typing.overload
    def __init__(self, source: java.lang.CharSequence, paint: TextPaint, outerwidth: int | java.jint | java.lang.Integer, align: Layout.Alignment, spacingMult: float | java.jfloat | java.lang.Float, spacingAdd: float | java.jfloat | java.lang.Float, metrics: BoringLayout.Metrics, includePad: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def __init__(self, source: java.lang.CharSequence, paint: TextPaint, outerWidth: int | java.jint | java.lang.Integer, align: Layout.Alignment, spacingMult: float | java.jfloat | java.lang.Float, spacingAdd: float | java.jfloat | java.lang.Float, metrics: BoringLayout.Metrics, includePad: bool | java.jboolean | java.lang.Boolean, ellipsize: TextUtils.TruncateAt, ellipsizedWidth: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, source: java.lang.CharSequence, paint: TextPaint, outerWidth: int | java.jint | java.lang.Integer, align: Layout.Alignment, spacingMult: float | java.jfloat | java.lang.Float, spacingAdd: float | java.jfloat | java.lang.Float, metrics: BoringLayout.Metrics, includePad: bool | java.jboolean | java.lang.Boolean, ellipsize: TextUtils.TruncateAt, ellipsizedWidth: int | java.jint | java.lang.Integer, useFallbackLineSpacing: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def computeDrawingBoundingBox(self) -> android.graphics.RectF: ...
    def draw(self, c: android.graphics.Canvas, highlight: android.graphics.Path, highlightpaint: android.graphics.Paint, cursorOffset: int | java.jint | java.lang.Integer, /) -> None: ...
    def ellipsized(self, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> None: ...
    def getBottomPadding(self) -> int: ...
    def getEllipsisCount(self, line: int | java.jint | java.lang.Integer, /) -> int: ...
    def getEllipsisStart(self, line: int | java.jint | java.lang.Integer, /) -> int: ...
    def getEllipsizedWidth(self) -> int: ...
    def getHeight(self) -> int: ...
    def getLineContainsTab(self, line: int | java.jint | java.lang.Integer, /) -> bool: ...
    def getLineCount(self) -> int: ...
    def getLineDescent(self, line: int | java.jint | java.lang.Integer, /) -> int: ...
    def getLineDirections(self, line: int | java.jint | java.lang.Integer, /) -> Layout.Directions: ...
    def getLineMax(self, line: int | java.jint | java.lang.Integer, /) -> float: ...
    def getLineStart(self, line: int | java.jint | java.lang.Integer, /) -> int: ...
    def getLineTop(self, line: int | java.jint | java.lang.Integer, /) -> int: ...
    def getLineWidth(self, line: int | java.jint | java.lang.Integer, /) -> float: ...
    def getParagraphDirection(self, line: int | java.jint | java.lang.Integer, /) -> int: ...
    def getTopPadding(self) -> int: ...
    @typing.overload
    @staticmethod
    def isBoring(text: java.lang.CharSequence, paint: TextPaint, /) -> BoringLayout.Metrics | None: ...
    @typing.overload
    @staticmethod
    def isBoring(text: java.lang.CharSequence, paint: TextPaint, metrics: BoringLayout.Metrics, /) -> BoringLayout.Metrics | None: ...
    @typing.overload
    @staticmethod
    def isBoring(text: java.lang.CharSequence, paint: TextPaint, textDir: TextDirectionHeuristic, useFallbackLineSpacing: bool | java.jboolean | java.lang.Boolean, metrics: BoringLayout.Metrics, /) -> BoringLayout.Metrics | None: ...
    def isFallbackLineSpacingEnabled(self) -> bool: ...
    @typing.overload
    @staticmethod
    def make(source: java.lang.CharSequence, paint: TextPaint, outerWidth: int | java.jint | java.lang.Integer, align: Layout.Alignment, spacingMult: float | java.jfloat | java.lang.Float, spacingAdd: float | java.jfloat | java.lang.Float, metrics: BoringLayout.Metrics, includePad: bool | java.jboolean | java.lang.Boolean, /) -> BoringLayout: ...
    @typing.overload
    @staticmethod
    def make(source: java.lang.CharSequence, paint: TextPaint, outerWidth: int | java.jint | java.lang.Integer, align: Layout.Alignment, metrics: BoringLayout.Metrics, includePad: bool | java.jboolean | java.lang.Boolean, ellipsize: TextUtils.TruncateAt, ellipsizedWidth: int | java.jint | java.lang.Integer, useFallbackLineSpacing: bool | java.jboolean | java.lang.Boolean, /) -> BoringLayout: ...
    @typing.overload
    @staticmethod
    def make(source: java.lang.CharSequence, paint: TextPaint, outerWidth: int | java.jint | java.lang.Integer, align: Layout.Alignment, spacingmult: float | java.jfloat | java.lang.Float, spacingadd: float | java.jfloat | java.lang.Float, metrics: BoringLayout.Metrics, includePad: bool | java.jboolean | java.lang.Boolean, ellipsize: TextUtils.TruncateAt, ellipsizedWidth: int | java.jint | java.lang.Integer, /) -> BoringLayout: ...
    @typing.overload
    def replaceOrMake(self, source: java.lang.CharSequence, paint: TextPaint, outerwidth: int | java.jint | java.lang.Integer, align: Layout.Alignment, spacingMult: float | java.jfloat | java.lang.Float, spacingAdd: float | java.jfloat | java.lang.Float, metrics: BoringLayout.Metrics, includePad: bool | java.jboolean | java.lang.Boolean, /) -> BoringLayout: ...
    @typing.overload
    def replaceOrMake(self, source: java.lang.CharSequence, paint: TextPaint, outerWidth: int | java.jint | java.lang.Integer, align: Layout.Alignment, metrics: BoringLayout.Metrics, includePad: bool | java.jboolean | java.lang.Boolean, ellipsize: TextUtils.TruncateAt, ellipsizedWidth: int | java.jint | java.lang.Integer, useFallbackLineSpacing: bool | java.jboolean | java.lang.Boolean, /) -> BoringLayout: ...
    @typing.overload
    def replaceOrMake(self, source: java.lang.CharSequence, paint: TextPaint, outerWidth: int | java.jint | java.lang.Integer, align: Layout.Alignment, spacingMult: float | java.jfloat | java.lang.Float, spacingAdd: float | java.jfloat | java.lang.Float, metrics: BoringLayout.Metrics, includePad: bool | java.jboolean | java.lang.Boolean, ellipsize: TextUtils.TruncateAt, ellipsizedWidth: int | java.jint | java.lang.Integer, /) -> BoringLayout: ...

    class Metrics(android.graphics.Paint.FontMetricsInt):
        width: int = ...
        def __init__(self) -> None: ...
        def getDrawingBoundingBox(self) -> android.graphics.RectF: ...
        def toString(self) -> str: ...

class ClipboardManager(java.lang.Object):
    def __init__(self) -> None: ...
    def getText(self) -> java.lang.CharSequence: ...
    def hasText(self) -> bool: ...
    def setText(self, arg1: java.lang.CharSequence, /) -> None: ...

class DynamicLayout(Layout):
    @typing.overload
    def __init__(self, base: java.lang.CharSequence, paint: TextPaint, width: int | java.jint | java.lang.Integer, align: Layout.Alignment, spacingmult: float | java.jfloat | java.lang.Float, spacingadd: float | java.jfloat | java.lang.Float, includepad: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def __init__(self, base: java.lang.CharSequence, display: java.lang.CharSequence, paint: TextPaint, width: int | java.jint | java.lang.Integer, align: Layout.Alignment, spacingmult: float | java.jfloat | java.lang.Float, spacingadd: float | java.jfloat | java.lang.Float, includepad: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def __init__(self, base: java.lang.CharSequence, display: java.lang.CharSequence, paint: TextPaint, width: int | java.jint | java.lang.Integer, align: Layout.Alignment, spacingmult: float | java.jfloat | java.lang.Float, spacingadd: float | java.jfloat | java.lang.Float, includepad: bool | java.jboolean | java.lang.Boolean, ellipsize: TextUtils.TruncateAt, ellipsizedWidth: int | java.jint | java.lang.Integer, /) -> None: ...
    def getBottomPadding(self) -> int: ...
    def getEllipsisCount(self, line: int | java.jint | java.lang.Integer, /) -> int: ...
    def getEllipsisStart(self, line: int | java.jint | java.lang.Integer, /) -> int: ...
    def getEllipsizedWidth(self) -> int: ...
    def getLineBreakConfig(self) -> android.graphics.text.LineBreakConfig: ...
    def getLineContainsTab(self, line: int | java.jint | java.lang.Integer, /) -> bool: ...
    def getLineCount(self) -> int: ...
    def getLineDescent(self, line: int | java.jint | java.lang.Integer, /) -> int: ...
    def getLineDirections(self, line: int | java.jint | java.lang.Integer, /) -> Layout.Directions: ...
    def getLineStart(self, line: int | java.jint | java.lang.Integer, /) -> int: ...
    def getLineTop(self, line: int | java.jint | java.lang.Integer, /) -> int: ...
    def getParagraphDirection(self, line: int | java.jint | java.lang.Integer, /) -> int: ...
    def getTopPadding(self) -> int: ...

    class Builder(java.lang.Object):
        def build(self) -> DynamicLayout: ...
        @staticmethod
        def obtain(base: java.lang.CharSequence, paint: TextPaint, width: int | java.jint | java.lang.Integer, /) -> DynamicLayout.Builder: ...
        def setAlignment(self, alignment: Layout.Alignment, /) -> DynamicLayout.Builder: ...
        def setBreakStrategy(self, breakStrategy: int | java.jint | java.lang.Integer, /) -> DynamicLayout.Builder: ...
        def setDisplayText(self, display: java.lang.CharSequence, /) -> DynamicLayout.Builder: ...
        def setEllipsize(self, ellipsize: TextUtils.TruncateAt, /) -> DynamicLayout.Builder: ...
        def setEllipsizedWidth(self, ellipsizedWidth: int | java.jint | java.lang.Integer, /) -> DynamicLayout.Builder: ...
        def setHyphenationFrequency(self, hyphenationFrequency: int | java.jint | java.lang.Integer, /) -> DynamicLayout.Builder: ...
        def setIncludePad(self, includePad: bool | java.jboolean | java.lang.Boolean, /) -> DynamicLayout.Builder: ...
        def setJustificationMode(self, justificationMode: int | java.jint | java.lang.Integer, /) -> DynamicLayout.Builder: ...
        def setLineBreakConfig(self, lineBreakConfig: android.graphics.text.LineBreakConfig, /) -> DynamicLayout.Builder: ...
        def setLineSpacing(self, spacingAdd: float | java.jfloat | java.lang.Float, spacingMult: float | java.jfloat | java.lang.Float, /) -> DynamicLayout.Builder: ...
        def setMinimumFontMetrics(self, minimumFontMetrics: android.graphics.Paint.FontMetrics, /) -> DynamicLayout.Builder: ...
        def setShiftDrawingOffsetForStartOverhang(self, shiftDrawingOffsetForStartOverhang: bool | java.jboolean | java.lang.Boolean, /) -> DynamicLayout.Builder: ...
        def setTextDirection(self, textDir: TextDirectionHeuristic, /) -> DynamicLayout.Builder: ...
        def setUseBoundsForWidth(self, useBoundsForWidth: bool | java.jboolean | java.lang.Boolean, /) -> DynamicLayout.Builder: ...
        def setUseLineSpacingFromFallbacks(self, useLineSpacingFromFallbacks: bool | java.jboolean | java.lang.Boolean, /) -> DynamicLayout.Builder: ...

class Editable(GetChars, Spannable, java.lang.Appendable, java.lang.CharSequence):
    @typing.overload
    def append(self, arg1: str | java.jchar | java.lang.Character, /) -> Editable: ...
    @typing.overload
    def append(self, arg1: java.lang.CharSequence, /) -> Editable: ...
    @typing.overload
    def append(self, arg1: java.lang.CharSequence, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> Editable: ...
    def clear(self) -> None: ...
    def clearSpans(self) -> None: ...
    def delete(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> Editable: ...
    def getFilters(self) -> java.chaquopy.JavaArray[InputFilter]: ...
    @typing.overload
    def insert(self, arg1: int | java.jint | java.lang.Integer, arg2: java.lang.CharSequence, /) -> Editable: ...
    @typing.overload
    def insert(self, arg1: int | java.jint | java.lang.Integer, arg2: java.lang.CharSequence, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> Editable: ...
    @typing.overload
    def replace(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.lang.CharSequence, /) -> Editable: ...
    @typing.overload
    def replace(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.lang.CharSequence, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> Editable: ...
    def setFilters(self, arg1: java.chaquopy.JavaArray[InputFilter], /) -> None: ...

    class Factory(java.lang.Object):
        def __init__(self) -> None: ...
        @staticmethod
        def getInstance() -> Editable.Factory: ...
        def newEditable(self, source: java.lang.CharSequence, /) -> Editable: ...

class EmojiConsistency(java.lang.Object):
    @staticmethod
    def getEmojiConsistencySet() -> java.util.Set[java.chaquopy.JavaArrayJInt]: ...

class GetChars(java.lang.CharSequence):
    def getChars(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: java.chaquopy.JavaArrayJChar, arg4: int | java.jint | java.lang.Integer, /) -> None: ...

class GraphemeClusterSegmentFinder(SegmentFinder):
    def __init__(self, text: java.lang.CharSequence, textPaint: TextPaint, /) -> None: ...
    def nextEndBoundary(self, offset: int | java.jint | java.lang.Integer, /) -> int: ...
    def nextStartBoundary(self, offset: int | java.jint | java.lang.Integer, /) -> int: ...
    def previousEndBoundary(self, offset: int | java.jint | java.lang.Integer, /) -> int: ...
    def previousStartBoundary(self, offset: int | java.jint | java.lang.Integer, /) -> int: ...

class Highlights(java.lang.Object):
    def getPaint(self, index: int | java.jint | java.lang.Integer, /) -> android.graphics.Paint: ...
    def getRanges(self, index: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJInt: ...
    def getSize(self) -> int: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def addRange(self, paint: android.graphics.Paint, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> Highlights.Builder: ...
        def addRanges(self, paint: android.graphics.Paint, /, *ranges: java.jint) -> Highlights.Builder: ...
        def build(self) -> Highlights: ...

class Html(java.lang.Object):
    FROM_HTML_MODE_COMPACT: typing.ClassVar[int] = ...
    FROM_HTML_MODE_LEGACY: typing.ClassVar[int] = ...
    FROM_HTML_OPTION_USE_CSS_COLORS: typing.ClassVar[int] = ...
    FROM_HTML_SEPARATOR_LINE_BREAK_BLOCKQUOTE: typing.ClassVar[int] = ...
    FROM_HTML_SEPARATOR_LINE_BREAK_DIV: typing.ClassVar[int] = ...
    FROM_HTML_SEPARATOR_LINE_BREAK_HEADING: typing.ClassVar[int] = ...
    FROM_HTML_SEPARATOR_LINE_BREAK_LIST: typing.ClassVar[int] = ...
    FROM_HTML_SEPARATOR_LINE_BREAK_LIST_ITEM: typing.ClassVar[int] = ...
    FROM_HTML_SEPARATOR_LINE_BREAK_PARAGRAPH: typing.ClassVar[int] = ...
    TO_HTML_PARAGRAPH_LINES_CONSECUTIVE: typing.ClassVar[int] = ...
    TO_HTML_PARAGRAPH_LINES_INDIVIDUAL: typing.ClassVar[int] = ...
    @staticmethod
    def escapeHtml(text: java.lang.CharSequence, /) -> str: ...
    @typing.overload
    @staticmethod
    def fromHtml(source: str | java.lang.String, /) -> Spanned: ...
    @typing.overload
    @staticmethod
    def fromHtml(source: str | java.lang.String, flags: int | java.jint | java.lang.Integer, /) -> Spanned: ...
    @typing.overload
    @staticmethod
    def fromHtml(source: str | java.lang.String, imageGetter: Html.ImageGetter, tagHandler: Html.TagHandler, /) -> Spanned: ...
    @typing.overload
    @staticmethod
    def fromHtml(source: str | java.lang.String, flags: int | java.jint | java.lang.Integer, imageGetter: Html.ImageGetter, tagHandler: Html.TagHandler, /) -> Spanned: ...
    @typing.overload
    @staticmethod
    def toHtml(text: Spanned, /) -> str: ...
    @typing.overload
    @staticmethod
    def toHtml(text: Spanned, option: int | java.jint | java.lang.Integer, /) -> str: ...

    class TagHandler(java.lang.Object):
        def handleTag(self, arg1: bool | java.jboolean | java.lang.Boolean, arg2: str | java.lang.String, arg3: Editable, arg4: org.xml.sax.XMLReader, /) -> None: ...

    class ImageGetter(java.lang.Object):
        def getDrawable(self, arg1: str | java.lang.String, /) -> android.graphics.drawable.Drawable: ...

class InputFilter(java.lang.Object):
    def filter(self, arg1: java.lang.CharSequence, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: Spanned, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, /) -> java.lang.CharSequence: ...

    class LengthFilter(InputFilter):
        def __init__(self, max: int | java.jint | java.lang.Integer, /) -> None: ...
        def filter(self, source: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, dest: Spanned, dstart: int | java.jint | java.lang.Integer, dend: int | java.jint | java.lang.Integer, /) -> java.lang.CharSequence: ...
        def getMax(self) -> int: ...

    class AllCaps(InputFilter):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, locale: java.util.Locale, /) -> None: ...
        def filter(self, source: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, dest: Spanned, dstart: int | java.jint | java.lang.Integer, dend: int | java.jint | java.lang.Integer, /) -> java.lang.CharSequence: ...

class InputType(java.lang.Object):
    TYPE_CLASS_DATETIME: typing.ClassVar[int] = ...
    TYPE_CLASS_NUMBER: typing.ClassVar[int] = ...
    TYPE_CLASS_PHONE: typing.ClassVar[int] = ...
    TYPE_CLASS_TEXT: typing.ClassVar[int] = ...
    TYPE_DATETIME_VARIATION_DATE: typing.ClassVar[int] = ...
    TYPE_DATETIME_VARIATION_NORMAL: typing.ClassVar[int] = ...
    TYPE_DATETIME_VARIATION_TIME: typing.ClassVar[int] = ...
    TYPE_MASK_CLASS: typing.ClassVar[int] = ...
    TYPE_MASK_FLAGS: typing.ClassVar[int] = ...
    TYPE_MASK_VARIATION: typing.ClassVar[int] = ...
    TYPE_NULL: typing.ClassVar[int] = ...
    TYPE_NUMBER_FLAG_DECIMAL: typing.ClassVar[int] = ...
    TYPE_NUMBER_FLAG_SIGNED: typing.ClassVar[int] = ...
    TYPE_NUMBER_VARIATION_NORMAL: typing.ClassVar[int] = ...
    TYPE_NUMBER_VARIATION_PASSWORD: typing.ClassVar[int] = ...
    TYPE_TEXT_FLAG_AUTO_COMPLETE: typing.ClassVar[int] = ...
    TYPE_TEXT_FLAG_AUTO_CORRECT: typing.ClassVar[int] = ...
    TYPE_TEXT_FLAG_CAP_CHARACTERS: typing.ClassVar[int] = ...
    TYPE_TEXT_FLAG_CAP_SENTENCES: typing.ClassVar[int] = ...
    TYPE_TEXT_FLAG_CAP_WORDS: typing.ClassVar[int] = ...
    TYPE_TEXT_FLAG_ENABLE_TEXT_CONVERSION_SUGGESTIONS: typing.ClassVar[int] = ...
    TYPE_TEXT_FLAG_IME_MULTI_LINE: typing.ClassVar[int] = ...
    TYPE_TEXT_FLAG_MULTI_LINE: typing.ClassVar[int] = ...
    TYPE_TEXT_FLAG_NO_SUGGESTIONS: typing.ClassVar[int] = ...
    TYPE_TEXT_VARIATION_EMAIL_ADDRESS: typing.ClassVar[int] = ...
    TYPE_TEXT_VARIATION_EMAIL_SUBJECT: typing.ClassVar[int] = ...
    TYPE_TEXT_VARIATION_FILTER: typing.ClassVar[int] = ...
    TYPE_TEXT_VARIATION_LONG_MESSAGE: typing.ClassVar[int] = ...
    TYPE_TEXT_VARIATION_NORMAL: typing.ClassVar[int] = ...
    TYPE_TEXT_VARIATION_PASSWORD: typing.ClassVar[int] = ...
    TYPE_TEXT_VARIATION_PERSON_NAME: typing.ClassVar[int] = ...
    TYPE_TEXT_VARIATION_PHONETIC: typing.ClassVar[int] = ...
    TYPE_TEXT_VARIATION_POSTAL_ADDRESS: typing.ClassVar[int] = ...
    TYPE_TEXT_VARIATION_SHORT_MESSAGE: typing.ClassVar[int] = ...
    TYPE_TEXT_VARIATION_URI: typing.ClassVar[int] = ...
    TYPE_TEXT_VARIATION_VISIBLE_PASSWORD: typing.ClassVar[int] = ...
    TYPE_TEXT_VARIATION_WEB_EDIT_TEXT: typing.ClassVar[int] = ...
    TYPE_TEXT_VARIATION_WEB_EMAIL_ADDRESS: typing.ClassVar[int] = ...
    TYPE_TEXT_VARIATION_WEB_PASSWORD: typing.ClassVar[int] = ...

class Layout(java.lang.Object):
    BREAK_STRATEGY_BALANCED: typing.ClassVar[int] = ...
    BREAK_STRATEGY_HIGH_QUALITY: typing.ClassVar[int] = ...
    BREAK_STRATEGY_SIMPLE: typing.ClassVar[int] = ...
    DEFAULT_LINESPACING_ADDITION: typing.ClassVar[float] = ...
    DEFAULT_LINESPACING_MULTIPLIER: typing.ClassVar[float] = ...
    DIR_LEFT_TO_RIGHT: typing.ClassVar[int] = ...
    DIR_RIGHT_TO_LEFT: typing.ClassVar[int] = ...
    HYPHENATION_FREQUENCY_FULL: typing.ClassVar[int] = ...
    HYPHENATION_FREQUENCY_FULL_FAST: typing.ClassVar[int] = ...
    HYPHENATION_FREQUENCY_NONE: typing.ClassVar[int] = ...
    HYPHENATION_FREQUENCY_NORMAL: typing.ClassVar[int] = ...
    HYPHENATION_FREQUENCY_NORMAL_FAST: typing.ClassVar[int] = ...
    INCLUSION_STRATEGY_ANY_OVERLAP: typing.ClassVar[Layout.TextInclusionStrategy] = ...
    INCLUSION_STRATEGY_CONTAINS_ALL: typing.ClassVar[Layout.TextInclusionStrategy] = ...
    INCLUSION_STRATEGY_CONTAINS_CENTER: typing.ClassVar[Layout.TextInclusionStrategy] = ...
    JUSTIFICATION_MODE_INTER_CHARACTER: typing.ClassVar[int] = ...
    JUSTIFICATION_MODE_INTER_WORD: typing.ClassVar[int] = ...
    JUSTIFICATION_MODE_NONE: typing.ClassVar[int] = ...
    def __init__(self, text: java.lang.CharSequence, paint: TextPaint, width: int | java.jint | java.lang.Integer, align: Layout.Alignment, spacingMult: float | java.jfloat | java.lang.Float, spacingAdd: float | java.jfloat | java.lang.Float, /) -> None: ...
    def computeDrawingBoundingBox(self) -> android.graphics.RectF: ...
    @typing.overload
    def draw(self, c: android.graphics.Canvas, /) -> None: ...
    @typing.overload
    def draw(self, canvas: android.graphics.Canvas, selectionHighlight: android.graphics.Path, selectionHighlightPaint: android.graphics.Paint, cursorOffsetVertical: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def draw(self, canvas: android.graphics.Canvas, highlightPaths: java.util.List[android.graphics.Path], highlightPaints: java.util.List[android.graphics.Paint], selectionPath: android.graphics.Path, selectionPaint: android.graphics.Paint, cursorOffsetVertical: int | java.jint | java.lang.Integer, /) -> None: ...
    def drawBackground(self, canvas: android.graphics.Canvas, /) -> None: ...
    def drawText(self, canvas: android.graphics.Canvas, /) -> None: ...
    def fillCharacterBounds(self, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, bounds: java.chaquopy.JavaArrayJFloat, boundsStart: int | java.jint | java.lang.Integer, /) -> None: ...
    def getAlignment(self) -> Layout.Alignment: ...
    def getBottomPadding(self) -> int: ...
    def getBreakStrategy(self) -> int: ...
    def getCursorPath(self, point: int | java.jint | java.lang.Integer, dest: android.graphics.Path, editingBuffer: java.lang.CharSequence, /) -> None: ...
    @typing.overload
    @staticmethod
    def getDesiredWidth(source: java.lang.CharSequence, paint: TextPaint, /) -> float: ...
    @typing.overload
    @staticmethod
    def getDesiredWidth(source: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, paint: TextPaint, /) -> float: ...
    def getEllipsisCount(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    def getEllipsisStart(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    def getEllipsize(self) -> TextUtils.TruncateAt | None: ...
    def getEllipsizedWidth(self) -> int: ...
    def getHeight(self) -> int: ...
    def getHyphenationFrequency(self) -> int: ...
    def getJustificationMode(self) -> int: ...
    def getLeftIndents(self) -> java.chaquopy.JavaArrayJInt | None: ...
    def getLineAscent(self, line: int | java.jint | java.lang.Integer, /) -> int: ...
    def getLineBaseline(self, line: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def getLineBottom(self, line: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def getLineBottom(self, line: int | java.jint | java.lang.Integer, includeLineSpacing: bool | java.jboolean | java.lang.Boolean, /) -> int: ...
    def getLineBounds(self, line: int | java.jint | java.lang.Integer, bounds: android.graphics.Rect, /) -> int: ...
    def getLineBreakConfig(self) -> android.graphics.text.LineBreakConfig: ...
    def getLineContainsTab(self, arg1: int | java.jint | java.lang.Integer, /) -> bool: ...
    def getLineCount(self) -> int: ...
    def getLineDescent(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    def getLineDirections(self, arg1: int | java.jint | java.lang.Integer, /) -> Layout.Directions: ...
    def getLineEnd(self, line: int | java.jint | java.lang.Integer, /) -> int: ...
    def getLineForOffset(self, offset: int | java.jint | java.lang.Integer, /) -> int: ...
    def getLineForVertical(self, vertical: int | java.jint | java.lang.Integer, /) -> int: ...
    def getLineLeft(self, line: int | java.jint | java.lang.Integer, /) -> float: ...
    def getLineLetterSpacingUnitCount(self, line: int | java.jint | java.lang.Integer, includeTrailingWhitespace: bool | java.jboolean | java.lang.Boolean, /) -> int: ...
    def getLineMax(self, line: int | java.jint | java.lang.Integer, /) -> float: ...
    def getLineRight(self, line: int | java.jint | java.lang.Integer, /) -> float: ...
    def getLineSpacingAmount(self) -> float: ...
    def getLineSpacingMultiplier(self) -> float: ...
    def getLineStart(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    def getLineTop(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    def getLineVisibleEnd(self, line: int | java.jint | java.lang.Integer, /) -> int: ...
    def getLineWidth(self, line: int | java.jint | java.lang.Integer, /) -> float: ...
    def getMaxLines(self) -> int: ...
    def getMinimumFontMetrics(self) -> android.graphics.Paint.FontMetrics | None: ...
    def getOffsetForHorizontal(self, line: int | java.jint | java.lang.Integer, horiz: float | java.jfloat | java.lang.Float, /) -> int: ...
    def getOffsetToLeftOf(self, offset: int | java.jint | java.lang.Integer, /) -> int: ...
    def getOffsetToRightOf(self, offset: int | java.jint | java.lang.Integer, /) -> int: ...
    def getPaint(self) -> TextPaint: ...
    def getParagraphAlignment(self, line: int | java.jint | java.lang.Integer, /) -> Layout.Alignment: ...
    def getParagraphDirection(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    def getParagraphLeft(self, line: int | java.jint | java.lang.Integer, /) -> int: ...
    def getParagraphRight(self, line: int | java.jint | java.lang.Integer, /) -> int: ...
    def getPrimaryHorizontal(self, offset: int | java.jint | java.lang.Integer, /) -> float: ...
    def getRangeForRect(self, area: android.graphics.RectF, segmentFinder: SegmentFinder, inclusionStrategy: Layout.TextInclusionStrategy, /) -> java.chaquopy.JavaArrayJInt | None: ...
    def getRightIndents(self) -> java.chaquopy.JavaArrayJInt | None: ...
    def getSecondaryHorizontal(self, offset: int | java.jint | java.lang.Integer, /) -> float: ...
    def getSelectionPath(self, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, dest: android.graphics.Path, /) -> None: ...
    def getShiftDrawingOffsetForStartOverhang(self) -> bool: ...
    def getSpacingAdd(self) -> float: ...
    def getSpacingMultiplier(self) -> float: ...
    def getText(self) -> java.lang.CharSequence: ...
    def getTextDirectionHeuristic(self) -> TextDirectionHeuristic: ...
    def getTopPadding(self) -> int: ...
    def getUseBoundsForWidth(self) -> bool: ...
    def getWidth(self) -> int: ...
    def increaseWidthTo(self, wid: int | java.jint | java.lang.Integer, /) -> None: ...
    def isFallbackLineSpacingEnabled(self) -> bool: ...
    def isFontPaddingIncluded(self) -> bool: ...
    def isRtlCharAt(self, offset: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isSpanned(self) -> bool: ...

    class TextInclusionStrategy(java.lang.Object):
        def isSegmentInside(self, arg1: android.graphics.RectF, arg2: android.graphics.RectF, /) -> bool: ...

    class Directions(java.lang.Object): ...

    class Builder(java.lang.Object):
        def __init__(self, text: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, paint: TextPaint, width: int | java.jint | java.lang.Integer, /) -> None: ...
        def build(self) -> Layout: ...
        def setAlignment(self, alignment: Layout.Alignment, /) -> Layout.Builder: ...
        def setBreakStrategy(self, breakStrategy: int | java.jint | java.lang.Integer, /) -> Layout.Builder: ...
        def setEllipsize(self, ellipsize: TextUtils.TruncateAt, /) -> Layout.Builder: ...
        def setEllipsizedWidth(self, ellipsizeWidth: int | java.jint | java.lang.Integer, /) -> Layout.Builder: ...
        def setFallbackLineSpacingEnabled(self, fallbackLineSpacing: bool | java.jboolean | java.lang.Boolean, /) -> Layout.Builder: ...
        def setFontPaddingIncluded(self, includeFontPadding: bool | java.jboolean | java.lang.Boolean, /) -> Layout.Builder: ...
        def setHyphenationFrequency(self, hyphenationFrequency: int | java.jint | java.lang.Integer, /) -> Layout.Builder: ...
        def setJustificationMode(self, justificationMode: int | java.jint | java.lang.Integer, /) -> Layout.Builder: ...
        def setLeftIndents(self, leftIndents: java.chaquopy.JavaArrayJInt, /) -> Layout.Builder: ...
        def setLineBreakConfig(self, lineBreakConfig: android.graphics.text.LineBreakConfig, /) -> Layout.Builder: ...
        def setLineSpacingAmount(self, amount: float | java.jfloat | java.lang.Float, /) -> Layout.Builder: ...
        def setLineSpacingMultiplier(self, multiplier: float | java.jfloat | java.lang.Float, /) -> Layout.Builder: ...
        def setMaxLines(self, maxLines: int | java.jint | java.lang.Integer, /) -> Layout.Builder: ...
        def setMinimumFontMetrics(self, minimumFontMetrics: android.graphics.Paint.FontMetrics, /) -> Layout.Builder: ...
        def setRightIndents(self, rightIndents: java.chaquopy.JavaArrayJInt, /) -> Layout.Builder: ...
        def setShiftDrawingOffsetForStartOverhang(self, shiftDrawingOffsetForStartOverhang: bool | java.jboolean | java.lang.Boolean, /) -> Layout.Builder: ...
        def setTextDirectionHeuristic(self, textDirection: TextDirectionHeuristic, /) -> Layout.Builder: ...
        def setUseBoundsForWidth(self, useBoundsForWidth: bool | java.jboolean | java.lang.Boolean, /) -> Layout.Builder: ...

    class Alignment(java.lang.Enum[Layout.Alignment]):
        ALIGN_CENTER: typing.ClassVar[Layout.Alignment] = ...
        ALIGN_NORMAL: typing.ClassVar[Layout.Alignment] = ...
        ALIGN_OPPOSITE: typing.ClassVar[Layout.Alignment] = ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> Layout.Alignment: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[Layout.Alignment]: ...

class LoginFilter(InputFilter):
    def filter(self, source: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, dest: Spanned, dstart: int | java.jint | java.lang.Integer, dend: int | java.jint | java.lang.Integer, /) -> java.lang.CharSequence: ...
    def isAllowed(self, arg1: str | java.jchar | java.lang.Character, /) -> bool: ...
    def onInvalidCharacter(self, c: str | java.jchar | java.lang.Character, /) -> None: ...
    def onStart(self) -> None: ...
    def onStop(self) -> None: ...

    class UsernameFilterGeneric(LoginFilter):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, appendInvalid: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def isAllowed(self, c: str | java.jchar | java.lang.Character, /) -> bool: ...

    class UsernameFilterGMail(LoginFilter):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, appendInvalid: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def isAllowed(self, c: str | java.jchar | java.lang.Character, /) -> bool: ...

    class PasswordFilterGMail(LoginFilter):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, appendInvalid: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def isAllowed(self, c: str | java.jchar | java.lang.Character, /) -> bool: ...

class NoCopySpan(java.lang.Object):

    class Concrete(NoCopySpan):
        def __init__(self) -> None: ...

class ParcelableSpan(android.os.Parcelable):
    def getSpanTypeId(self) -> int: ...

class PrecomputedText(Spannable):
    def charAt(self, index: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def create(text: java.lang.CharSequence, params: PrecomputedText.Params, /) -> PrecomputedText: ...
    def getBounds(self, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, bounds: android.graphics.Rect, /) -> None: ...
    def getFontMetricsInt(self, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, outMetrics: android.graphics.Paint.FontMetricsInt, /) -> None: ...
    def getParagraphCount(self) -> int: ...
    def getParagraphEnd(self, paraIndex: int | java.jint | java.lang.Integer, /) -> int: ...
    def getParagraphStart(self, paraIndex: int | java.jint | java.lang.Integer, /) -> int: ...
    def getParams(self) -> PrecomputedText.Params: ...
    def getSpanEnd(self, tag: java.lang.Object | int | bool | float | str, /) -> int: ...
    def getSpanFlags(self, tag: java.lang.Object | int | bool | float | str, /) -> int: ...
    def getSpanStart(self, tag: java.lang.Object | int | bool | float | str, /) -> int: ...
    _getSpans__T = typing.TypeVar('_getSpans__T')  # <T>
    def getSpans(self, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, type: typing.Type[_getSpans__T], /) -> java.chaquopy.JavaArray[_getSpans__T]: ...
    def getWidth(self, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> float: ...
    def length(self) -> int: ...
    def nextSpanTransition(self, start: int | java.jint | java.lang.Integer, limit: int | java.jint | java.lang.Integer, type: typing.Type, /) -> int: ...
    def removeSpan(self, what: java.lang.Object | int | bool | float | str, /) -> None: ...
    def setSpan(self, what: java.lang.Object | int | bool | float | str, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def subSequence(self, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> java.lang.CharSequence: ...
    def toString(self) -> str: ...

    class Params(java.lang.Object):
        def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getBreakStrategy(self) -> int: ...
        def getHyphenationFrequency(self) -> int: ...
        def getLineBreakConfig(self) -> android.graphics.text.LineBreakConfig: ...
        def getTextDirection(self) -> TextDirectionHeuristic: ...
        def getTextPaint(self) -> TextPaint: ...
        def hashCode(self) -> int: ...
        def toString(self) -> str: ...

        class Builder(java.lang.Object):
            @typing.overload
            def __init__(self, params: PrecomputedText.Params, /) -> None: ...
            @typing.overload
            def __init__(self, paint: TextPaint, /) -> None: ...
            def build(self) -> PrecomputedText.Params: ...
            def setBreakStrategy(self, strategy: int | java.jint | java.lang.Integer, /) -> PrecomputedText.Params.Builder: ...
            def setHyphenationFrequency(self, frequency: int | java.jint | java.lang.Integer, /) -> PrecomputedText.Params.Builder: ...
            def setLineBreakConfig(self, lineBreakConfig: android.graphics.text.LineBreakConfig, /) -> PrecomputedText.Params.Builder: ...
            def setTextDirection(self, textDir: TextDirectionHeuristic, /) -> PrecomputedText.Params.Builder: ...

class SegmentFinder(java.lang.Object):
    DONE: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    def nextEndBoundary(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    def nextStartBoundary(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    def previousEndBoundary(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    def previousStartBoundary(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...

    class PrescribedSegmentFinder(SegmentFinder):
        def __init__(self, segments: java.chaquopy.JavaArrayJInt, /) -> None: ...
        def nextEndBoundary(self, offset: int | java.jint | java.lang.Integer, /) -> int: ...
        def nextStartBoundary(self, offset: int | java.jint | java.lang.Integer, /) -> int: ...
        def previousEndBoundary(self, offset: int | java.jint | java.lang.Integer, /) -> int: ...
        def previousStartBoundary(self, offset: int | java.jint | java.lang.Integer, /) -> int: ...

class Selection(java.lang.Object):
    SELECTION_END: typing.ClassVar[java.lang.Object] = ...
    SELECTION_START: typing.ClassVar[java.lang.Object] = ...
    @staticmethod
    def extendDown(text: Spannable, layout: Layout, /) -> bool: ...
    @staticmethod
    def extendLeft(text: Spannable, layout: Layout, /) -> bool: ...
    @staticmethod
    def extendRight(text: Spannable, layout: Layout, /) -> bool: ...
    @staticmethod
    def extendSelection(text: Spannable, index: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def extendToLeftEdge(text: Spannable, layout: Layout, /) -> bool: ...
    @staticmethod
    def extendToParagraphEnd(text: Spannable, /) -> bool: ...
    @staticmethod
    def extendToParagraphStart(text: Spannable, /) -> bool: ...
    @staticmethod
    def extendToRightEdge(text: Spannable, layout: Layout, /) -> bool: ...
    @staticmethod
    def extendUp(text: Spannable, layout: Layout, /) -> bool: ...
    @staticmethod
    def getSelectionEnd(text: java.lang.CharSequence, /) -> int: ...
    @staticmethod
    def getSelectionStart(text: java.lang.CharSequence, /) -> int: ...
    @staticmethod
    def moveDown(text: Spannable, layout: Layout, /) -> bool: ...
    @staticmethod
    def moveLeft(text: Spannable, layout: Layout, /) -> bool: ...
    @staticmethod
    def moveRight(text: Spannable, layout: Layout, /) -> bool: ...
    @staticmethod
    def moveToLeftEdge(text: Spannable, layout: Layout, /) -> bool: ...
    @staticmethod
    def moveToParagraphEnd(text: Spannable, layout: Layout, /) -> bool: ...
    @staticmethod
    def moveToParagraphStart(text: Spannable, layout: Layout, /) -> bool: ...
    @staticmethod
    def moveToRightEdge(text: Spannable, layout: Layout, /) -> bool: ...
    @staticmethod
    def moveUp(text: Spannable, layout: Layout, /) -> bool: ...
    @staticmethod
    def removeSelection(text: Spannable, /) -> None: ...
    @staticmethod
    def selectAll(text: Spannable, /) -> None: ...
    @typing.overload
    @staticmethod
    def setSelection(text: Spannable, index: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    @staticmethod
    def setSelection(text: Spannable, start: int | java.jint | java.lang.Integer, stop: int | java.jint | java.lang.Integer, /) -> None: ...

class SpanWatcher(NoCopySpan):
    def onSpanAdded(self, arg1: Spannable, arg2: java.lang.Object | int | bool | float | str, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    def onSpanChanged(self, arg1: Spannable, arg2: java.lang.Object | int | bool | float | str, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, /) -> None: ...
    def onSpanRemoved(self, arg1: Spannable, arg2: java.lang.Object | int | bool | float | str, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...

class Spannable(Spanned):
    def removeSpan(self, arg1: java.lang.Object | int | bool | float | str, /) -> None: ...
    def setSpan(self, arg1: java.lang.Object | int | bool | float | str, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...

    class Factory(java.lang.Object):
        def __init__(self) -> None: ...
        @staticmethod
        def getInstance() -> Spannable.Factory: ...
        def newSpannable(self, source: java.lang.CharSequence, /) -> Spannable: ...

class SpannableString(GetChars, Spannable, java.lang.CharSequence):
    def __init__(self, source: java.lang.CharSequence, /) -> None: ...
    def charAt(self, i: int | java.jint | java.lang.Integer, /) -> str: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getChars(self, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, dest: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, /) -> None: ...
    def getSpanEnd(self, what: java.lang.Object | int | bool | float | str, /) -> int: ...
    def getSpanFlags(self, what: java.lang.Object | int | bool | float | str, /) -> int: ...
    def getSpanStart(self, what: java.lang.Object | int | bool | float | str, /) -> int: ...
    _getSpans__T = typing.TypeVar('_getSpans__T')  # <T>
    def getSpans(self, queryStart: int | java.jint | java.lang.Integer, queryEnd: int | java.jint | java.lang.Integer, kind: typing.Type[_getSpans__T], /) -> java.chaquopy.JavaArray[_getSpans__T]: ...
    def hashCode(self) -> int: ...
    def length(self) -> int: ...
    def nextSpanTransition(self, start: int | java.jint | java.lang.Integer, limit: int | java.jint | java.lang.Integer, kind: typing.Type, /) -> int: ...
    def removeSpan(self, what: java.lang.Object | int | bool | float | str, /) -> None: ...
    def setSpan(self, what: java.lang.Object | int | bool | float | str, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def subSequence(self, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> java.lang.CharSequence: ...
    def toString(self) -> str: ...
    @staticmethod
    def valueOf(source: java.lang.CharSequence, /) -> SpannableString: ...

class SpannableStringBuilder(Editable, GetChars, Spannable, java.lang.Appendable, java.lang.CharSequence):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, text: java.lang.CharSequence, /) -> None: ...
    @typing.overload
    def __init__(self, text: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def append(self, text: str | java.jchar | java.lang.Character, /) -> SpannableStringBuilder: ...
    @typing.overload
    def append(self, text: java.lang.CharSequence, /) -> SpannableStringBuilder: ...
    @typing.overload
    def append(self, text: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> SpannableStringBuilder: ...
    @typing.overload
    def append(self, text: java.lang.CharSequence, what: java.lang.Object | int | bool | float | str, flags: int | java.jint | java.lang.Integer, /) -> SpannableStringBuilder: ...
    def charAt(self, where: int | java.jint | java.lang.Integer, /) -> str: ...
    def clear(self) -> None: ...
    def clearSpans(self) -> None: ...
    def delete(self, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> SpannableStringBuilder: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getChars(self, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, dest: java.chaquopy.JavaArrayJChar, destoff: int | java.jint | java.lang.Integer, /) -> None: ...
    def getFilters(self) -> java.chaquopy.JavaArray[InputFilter]: ...
    def getSpanEnd(self, what: java.lang.Object | int | bool | float | str, /) -> int: ...
    def getSpanFlags(self, what: java.lang.Object | int | bool | float | str, /) -> int: ...
    def getSpanStart(self, what: java.lang.Object | int | bool | float | str, /) -> int: ...
    _getSpans__T = typing.TypeVar('_getSpans__T')  # <T>
    def getSpans(self, queryStart: int | java.jint | java.lang.Integer, queryEnd: int | java.jint | java.lang.Integer, kind: typing.Type[_getSpans__T], /) -> java.chaquopy.JavaArray[_getSpans__T]: ...
    def getTextRunCursor(self, contextStart: int | java.jint | java.lang.Integer, contextEnd: int | java.jint | java.lang.Integer, dir: int | java.jint | java.lang.Integer, offset: int | java.jint | java.lang.Integer, cursorOpt: int | java.jint | java.lang.Integer, p: android.graphics.Paint, /) -> int: ...
    def getTextWatcherDepth(self) -> int: ...
    def hashCode(self) -> int: ...
    @typing.overload
    def insert(self, where: int | java.jint | java.lang.Integer, tb: java.lang.CharSequence, /) -> SpannableStringBuilder: ...
    @typing.overload
    def insert(self, where: int | java.jint | java.lang.Integer, tb: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> SpannableStringBuilder: ...
    def length(self) -> int: ...
    def nextSpanTransition(self, start: int | java.jint | java.lang.Integer, limit: int | java.jint | java.lang.Integer, kind: typing.Type, /) -> int: ...
    def removeSpan(self, what: java.lang.Object | int | bool | float | str, /) -> None: ...
    @typing.overload
    def replace(self, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, tb: java.lang.CharSequence, /) -> SpannableStringBuilder: ...
    @typing.overload
    def replace(self, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, tb: java.lang.CharSequence, tbstart: int | java.jint | java.lang.Integer, tbend: int | java.jint | java.lang.Integer, /) -> SpannableStringBuilder: ...
    def setFilters(self, filters: java.chaquopy.JavaArray[InputFilter], /) -> None: ...
    def setSpan(self, what: java.lang.Object | int | bool | float | str, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def subSequence(self, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> java.lang.CharSequence: ...
    def toString(self) -> str: ...
    @staticmethod
    def valueOf(source: java.lang.CharSequence, /) -> SpannableStringBuilder: ...

class Spanned(java.lang.CharSequence):
    SPAN_COMPOSING: typing.ClassVar[int] = ...
    SPAN_EXCLUSIVE_EXCLUSIVE: typing.ClassVar[int] = ...
    SPAN_EXCLUSIVE_INCLUSIVE: typing.ClassVar[int] = ...
    SPAN_INCLUSIVE_EXCLUSIVE: typing.ClassVar[int] = ...
    SPAN_INCLUSIVE_INCLUSIVE: typing.ClassVar[int] = ...
    SPAN_INTERMEDIATE: typing.ClassVar[int] = ...
    SPAN_MARK_MARK: typing.ClassVar[int] = ...
    SPAN_MARK_POINT: typing.ClassVar[int] = ...
    SPAN_PARAGRAPH: typing.ClassVar[int] = ...
    SPAN_POINT_MARK: typing.ClassVar[int] = ...
    SPAN_POINT_MARK_MASK: typing.ClassVar[int] = ...
    SPAN_POINT_POINT: typing.ClassVar[int] = ...
    SPAN_PRIORITY: typing.ClassVar[int] = ...
    SPAN_PRIORITY_SHIFT: typing.ClassVar[int] = ...
    SPAN_USER: typing.ClassVar[int] = ...
    SPAN_USER_SHIFT: typing.ClassVar[int] = ...
    def getSpanEnd(self, arg1: java.lang.Object | int | bool | float | str, /) -> int: ...
    def getSpanFlags(self, arg1: java.lang.Object | int | bool | float | str, /) -> int: ...
    def getSpanStart(self, arg1: java.lang.Object | int | bool | float | str, /) -> int: ...
    _getSpans__T = typing.TypeVar('_getSpans__T')  # <T>
    def getSpans(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: typing.Type[_getSpans__T], /) -> java.chaquopy.JavaArray[_getSpans__T]: ...
    def nextSpanTransition(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: typing.Type, /) -> int: ...

class SpannedString(GetChars, Spanned, java.lang.CharSequence):
    def __init__(self, source: java.lang.CharSequence, /) -> None: ...
    def charAt(self, i: int | java.jint | java.lang.Integer, /) -> str: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getChars(self, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, dest: java.chaquopy.JavaArrayJChar, off: int | java.jint | java.lang.Integer, /) -> None: ...
    def getSpanEnd(self, what: java.lang.Object | int | bool | float | str, /) -> int: ...
    def getSpanFlags(self, what: java.lang.Object | int | bool | float | str, /) -> int: ...
    def getSpanStart(self, what: java.lang.Object | int | bool | float | str, /) -> int: ...
    _getSpans__T = typing.TypeVar('_getSpans__T')  # <T>
    def getSpans(self, queryStart: int | java.jint | java.lang.Integer, queryEnd: int | java.jint | java.lang.Integer, kind: typing.Type[_getSpans__T], /) -> java.chaquopy.JavaArray[_getSpans__T]: ...
    def hashCode(self) -> int: ...
    def length(self) -> int: ...
    def nextSpanTransition(self, start: int | java.jint | java.lang.Integer, limit: int | java.jint | java.lang.Integer, kind: typing.Type, /) -> int: ...
    def subSequence(self, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> java.lang.CharSequence: ...
    def toString(self) -> str: ...
    @staticmethod
    def valueOf(source: java.lang.CharSequence, /) -> SpannedString: ...

class StaticLayout(Layout):
    @typing.overload
    def __init__(self, source: java.lang.CharSequence, paint: TextPaint, width: int | java.jint | java.lang.Integer, align: Layout.Alignment, spacingmult: float | java.jfloat | java.lang.Float, spacingadd: float | java.jfloat | java.lang.Float, includepad: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def __init__(self, source: java.lang.CharSequence, bufstart: int | java.jint | java.lang.Integer, bufend: int | java.jint | java.lang.Integer, paint: TextPaint, outerwidth: int | java.jint | java.lang.Integer, align: Layout.Alignment, spacingmult: float | java.jfloat | java.lang.Float, spacingadd: float | java.jfloat | java.lang.Float, includepad: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def __init__(self, source: java.lang.CharSequence, bufstart: int | java.jint | java.lang.Integer, bufend: int | java.jint | java.lang.Integer, paint: TextPaint, outerwidth: int | java.jint | java.lang.Integer, align: Layout.Alignment, spacingmult: float | java.jfloat | java.lang.Float, spacingadd: float | java.jfloat | java.lang.Float, includepad: bool | java.jboolean | java.lang.Boolean, ellipsize: TextUtils.TruncateAt, ellipsizedWidth: int | java.jint | java.lang.Integer, /) -> None: ...
    def computeDrawingBoundingBox(self) -> android.graphics.RectF: ...
    def getBottomPadding(self) -> int: ...
    def getEllipsisCount(self, line: int | java.jint | java.lang.Integer, /) -> int: ...
    def getEllipsisStart(self, line: int | java.jint | java.lang.Integer, /) -> int: ...
    def getLineContainsTab(self, line: int | java.jint | java.lang.Integer, /) -> bool: ...
    def getLineCount(self) -> int: ...
    def getLineDescent(self, line: int | java.jint | java.lang.Integer, /) -> int: ...
    def getLineDirections(self, line: int | java.jint | java.lang.Integer, /) -> Layout.Directions: ...
    def getLineForVertical(self, vertical: int | java.jint | java.lang.Integer, /) -> int: ...
    def getLineStart(self, line: int | java.jint | java.lang.Integer, /) -> int: ...
    def getLineTop(self, line: int | java.jint | java.lang.Integer, /) -> int: ...
    def getParagraphDirection(self, line: int | java.jint | java.lang.Integer, /) -> int: ...
    def getTopPadding(self) -> int: ...

    class Builder(java.lang.Object):
        def build(self) -> StaticLayout: ...
        @staticmethod
        def obtain(source: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, paint: TextPaint, width: int | java.jint | java.lang.Integer, /) -> StaticLayout.Builder: ...
        def setAlignment(self, alignment: Layout.Alignment, /) -> StaticLayout.Builder: ...
        def setBreakStrategy(self, breakStrategy: int | java.jint | java.lang.Integer, /) -> StaticLayout.Builder: ...
        def setEllipsize(self, ellipsize: TextUtils.TruncateAt, /) -> StaticLayout.Builder: ...
        def setEllipsizedWidth(self, ellipsizedWidth: int | java.jint | java.lang.Integer, /) -> StaticLayout.Builder: ...
        def setHyphenationFrequency(self, hyphenationFrequency: int | java.jint | java.lang.Integer, /) -> StaticLayout.Builder: ...
        def setIncludePad(self, includePad: bool | java.jboolean | java.lang.Boolean, /) -> StaticLayout.Builder: ...
        def setIndents(self, leftIndents: java.chaquopy.JavaArrayJInt, rightIndents: java.chaquopy.JavaArrayJInt, /) -> StaticLayout.Builder: ...
        def setJustificationMode(self, justificationMode: int | java.jint | java.lang.Integer, /) -> StaticLayout.Builder: ...
        def setLineBreakConfig(self, lineBreakConfig: android.graphics.text.LineBreakConfig, /) -> StaticLayout.Builder: ...
        def setLineSpacing(self, spacingAdd: float | java.jfloat | java.lang.Float, spacingMult: float | java.jfloat | java.lang.Float, /) -> StaticLayout.Builder: ...
        def setMaxLines(self, maxLines: int | java.jint | java.lang.Integer, /) -> StaticLayout.Builder: ...
        def setMinimumFontMetrics(self, minimumFontMetrics: android.graphics.Paint.FontMetrics, /) -> StaticLayout.Builder: ...
        def setShiftDrawingOffsetForStartOverhang(self, shiftDrawingOffsetForStartOverhang: bool | java.jboolean | java.lang.Boolean, /) -> StaticLayout.Builder: ...
        def setText(self, source: java.lang.CharSequence, /) -> StaticLayout.Builder: ...
        def setTextDirection(self, textDir: TextDirectionHeuristic, /) -> StaticLayout.Builder: ...
        def setUseBoundsForWidth(self, useBoundsForWidth: bool | java.jboolean | java.lang.Boolean, /) -> StaticLayout.Builder: ...
        def setUseLineSpacingFromFallbacks(self, useLineSpacingFromFallbacks: bool | java.jboolean | java.lang.Boolean, /) -> StaticLayout.Builder: ...

class TextDirectionHeuristic(java.lang.Object):
    @typing.overload
    def isRtl(self, arg1: java.lang.CharSequence, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    def isRtl(self, arg1: java.chaquopy.JavaArrayJChar, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> bool: ...

class TextDirectionHeuristics(java.lang.Object):
    ANYRTL_LTR: typing.ClassVar[TextDirectionHeuristic] = ...
    FIRSTSTRONG_LTR: typing.ClassVar[TextDirectionHeuristic] = ...
    FIRSTSTRONG_RTL: typing.ClassVar[TextDirectionHeuristic] = ...
    LOCALE: typing.ClassVar[TextDirectionHeuristic] = ...
    LTR: typing.ClassVar[TextDirectionHeuristic] = ...
    RTL: typing.ClassVar[TextDirectionHeuristic] = ...
    def __init__(self) -> None: ...

class TextPaint(android.graphics.Paint):
    baselineShift: int = ...
    bgColor: int = ...
    density: float = ...
    drawableState: java.chaquopy.JavaArrayJInt = ...
    linkColor: int = ...
    underlineColor: int = ...
    underlineThickness: float = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, p: android.graphics.Paint, /) -> None: ...
    def getUnderlineThickness(self) -> float: ...
    def set(self, tp: TextPaint, /) -> None: ...

class TextShaper(java.lang.Object):
    @staticmethod
    def shapeText(text: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, count: int | java.jint | java.lang.Integer, dir: TextDirectionHeuristic, paint: TextPaint, consumer: TextShaper.GlyphsConsumer, /) -> None: ...

    class GlyphsConsumer(java.lang.Object):
        def accept(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, arg3: android.graphics.text.PositionedGlyphs, arg4: TextPaint, /) -> None: ...

class TextUtils(java.lang.Object):
    CAP_MODE_CHARACTERS: typing.ClassVar[int] = ...
    CAP_MODE_SENTENCES: typing.ClassVar[int] = ...
    CAP_MODE_WORDS: typing.ClassVar[int] = ...
    CHAR_SEQUENCE_CREATOR: typing.ClassVar[android.os.Parcelable.Creator[java.lang.CharSequence]] = ...
    SAFE_STRING_FLAG_FIRST_LINE: typing.ClassVar[int] = ...
    SAFE_STRING_FLAG_SINGLE_LINE: typing.ClassVar[int] = ...
    SAFE_STRING_FLAG_TRIM: typing.ClassVar[int] = ...
    @staticmethod
    def commaEllipsize(text: java.lang.CharSequence, p: TextPaint, avail: float | java.jfloat | java.lang.Float, oneMore: str | java.lang.String, more: str | java.lang.String, /) -> java.lang.CharSequence: ...
    @staticmethod
    def concat(*text: java.lang.CharSequence) -> java.lang.CharSequence: ...
    @staticmethod
    def copySpansFrom(source: Spanned, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, kind: typing.Type, dest: Spannable, destoff: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def dumpSpans(cs: java.lang.CharSequence, printer: android.util.Printer, prefix: str | java.lang.String, /) -> None: ...
    @typing.overload
    @staticmethod
    def ellipsize(text: java.lang.CharSequence, p: TextPaint, avail: float | java.jfloat | java.lang.Float, where: TextUtils.TruncateAt, /) -> java.lang.CharSequence | None: ...
    @typing.overload
    @staticmethod
    def ellipsize(text: java.lang.CharSequence, paint: TextPaint, avail: float | java.jfloat | java.lang.Float, where: TextUtils.TruncateAt, preserveLength: bool | java.jboolean | java.lang.Boolean, callback: TextUtils.EllipsizeCallback, /) -> java.lang.CharSequence | None: ...
    @staticmethod
    def equals(a: java.lang.CharSequence, b: java.lang.CharSequence, /) -> bool: ...
    @staticmethod
    def expandTemplate(template: java.lang.CharSequence, /, *values: java.lang.CharSequence) -> java.lang.CharSequence: ...
    @staticmethod
    def getCapsMode(cs: java.lang.CharSequence, off: int | java.jint | java.lang.Integer, reqModes: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def getChars(s: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, dest: java.chaquopy.JavaArrayJChar, destoff: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def getLayoutDirectionFromLocale(locale: java.util.Locale, /) -> int: ...
    @staticmethod
    def getOffsetAfter(text: java.lang.CharSequence, offset: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def getOffsetBefore(text: java.lang.CharSequence, offset: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def getReverse(source: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> java.lang.CharSequence: ...
    @staticmethod
    def getTrimmedLength(s: java.lang.CharSequence, /) -> int: ...
    @staticmethod
    def htmlEncode(s: str | java.lang.String, /) -> str: ...
    @typing.overload
    @staticmethod
    def indexOf(s: java.lang.CharSequence, ch: str | java.jchar | java.lang.Character, /) -> int: ...
    @typing.overload
    @staticmethod
    def indexOf(s: java.lang.CharSequence, needle: java.lang.CharSequence, /) -> int: ...
    @typing.overload
    @staticmethod
    def indexOf(s: java.lang.CharSequence, ch: str | java.jchar | java.lang.Character, start: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    @staticmethod
    def indexOf(s: java.lang.CharSequence, needle: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    @staticmethod
    def indexOf(s: java.lang.CharSequence, ch: str | java.jchar | java.lang.Character, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    @staticmethod
    def indexOf(s: java.lang.CharSequence, needle: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def isDigitsOnly(str: java.lang.CharSequence, /) -> bool: ...
    @staticmethod
    def isEmpty(str: java.lang.CharSequence, /) -> bool: ...
    @typing.overload
    @staticmethod
    def isGraphic(c: str | java.jchar | java.lang.Character, /) -> bool: ...
    @typing.overload
    @staticmethod
    def isGraphic(str: java.lang.CharSequence, /) -> bool: ...
    @typing.overload
    @staticmethod
    def join(delimiter: java.lang.CharSequence, tokens: java.lang.Iterable, /) -> str: ...
    @typing.overload
    @staticmethod
    def join(delimiter: java.lang.CharSequence, tokens: java.chaquopy.JavaArray[java.lang.Object], /) -> str: ...
    @typing.overload
    @staticmethod
    def lastIndexOf(s: java.lang.CharSequence, ch: str | java.jchar | java.lang.Character, /) -> int: ...
    @typing.overload
    @staticmethod
    def lastIndexOf(s: java.lang.CharSequence, ch: str | java.jchar | java.lang.Character, last: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    @staticmethod
    def lastIndexOf(s: java.lang.CharSequence, ch: str | java.jchar | java.lang.Character, start: int | java.jint | java.lang.Integer, last: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def listEllipsize(context: android.content.Context, elements: java.util.List[java.lang.CharSequence], separator: str | java.lang.String, paint: TextPaint, avail: float | java.jfloat | java.lang.Float, moreId: int | java.jint | java.lang.Integer, /) -> java.lang.CharSequence: ...
    @staticmethod
    def makeSafeForPresentation(unclean: str | java.lang.String, maxCharactersToConsider: int | java.jint | java.lang.Integer, ellipsizeDip: float | java.jfloat | java.lang.Float, flags: int | java.jint | java.lang.Integer, /) -> java.lang.CharSequence: ...
    @staticmethod
    def regionMatches(one: java.lang.CharSequence, toffset: int | java.jint | java.lang.Integer, two: java.lang.CharSequence, ooffset: int | java.jint | java.lang.Integer, len: int | java.jint | java.lang.Integer, /) -> bool: ...
    @staticmethod
    def replace(template: java.lang.CharSequence, sources: java.chaquopy.JavaArray[java.lang.String], destinations: java.chaquopy.JavaArray[java.lang.CharSequence], /) -> java.lang.CharSequence: ...
    @typing.overload
    @staticmethod
    def split(text: str | java.lang.String, expression: str | java.lang.String, /) -> java.chaquopy.JavaArray[java.lang.String]: ...
    @typing.overload
    @staticmethod
    def split(text: str | java.lang.String, pattern: java.util.regex.Pattern, /) -> java.chaquopy.JavaArray[java.lang.String]: ...
    @staticmethod
    def stringOrSpannedString(source: java.lang.CharSequence, /) -> java.lang.CharSequence: ...
    @staticmethod
    def substring(source: java.lang.CharSequence, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> str: ...
    @staticmethod
    def writeToParcel(cs: java.lang.CharSequence, p: android.os.Parcel, parcelableFlags: int | java.jint | java.lang.Integer, /) -> None: ...

    class TruncateAt(java.lang.Enum[TextUtils.TruncateAt]):
        END: typing.ClassVar[TextUtils.TruncateAt] = ...
        MARQUEE: typing.ClassVar[TextUtils.TruncateAt] = ...
        MIDDLE: typing.ClassVar[TextUtils.TruncateAt] = ...
        START: typing.ClassVar[TextUtils.TruncateAt] = ...
        @staticmethod
        def valueOf(name: str | java.lang.String, /) -> TextUtils.TruncateAt: ...
        @staticmethod
        def values() -> java.chaquopy.JavaArray[TextUtils.TruncateAt]: ...

    class StringSplitter(java.lang.Iterable[java.lang.String]):
        def setString(self, arg1: str | java.lang.String, /) -> None: ...

    class SimpleStringSplitter(TextUtils.StringSplitter, java.util.Iterator[java.lang.String]):
        def __init__(self, delimiter: str | java.jchar | java.lang.Character, /) -> None: ...
        def hasNext(self) -> bool: ...
        def iterator(self) -> java.util.Iterator[java.lang.String]: ...
        def next(self) -> str: ...
        def remove(self) -> None: ...
        def setString(self, string: str | java.lang.String, /) -> None: ...

    class EllipsizeCallback(java.lang.Object):
        def ellipsized(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...

class TextWatcher(NoCopySpan):
    def afterTextChanged(self, arg1: Editable, /) -> None: ...
    def beforeTextChanged(self, arg1: java.lang.CharSequence, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...
    def onTextChanged(self, arg1: java.lang.CharSequence, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> None: ...

class WordSegmentFinder(SegmentFinder):
    def __init__(self, text: java.lang.CharSequence, locale: android.icu.util.ULocale, /) -> None: ...
    def nextEndBoundary(self, offset: int | java.jint | java.lang.Integer, /) -> int: ...
    def nextStartBoundary(self, offset: int | java.jint | java.lang.Integer, /) -> int: ...
    def previousEndBoundary(self, offset: int | java.jint | java.lang.Integer, /) -> int: ...
    def previousStartBoundary(self, offset: int | java.jint | java.lang.Integer, /) -> int: ...



import typing

import java.io
import java.lang
import javax.xml.transform

class StreamResult(javax.xml.transform.Result):
    FEATURE: typing.ClassVar[str] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, f: java.io.File, /) -> None: ...
    @typing.overload
    def __init__(self, outputStream: java.io.OutputStream, /) -> None: ...
    @typing.overload
    def __init__(self, writer: java.io.Writer, /) -> None: ...
    @typing.overload
    def __init__(self, systemId: str | java.lang.String, /) -> None: ...
    def getOutputStream(self) -> java.io.OutputStream: ...
    def getSystemId(self) -> str: ...
    def getWriter(self) -> java.io.Writer: ...
    def setOutputStream(self, outputStream: java.io.OutputStream, /) -> None: ...
    @typing.overload
    def setSystemId(self, f: java.io.File, /) -> None: ...
    @typing.overload
    def setSystemId(self, systemId: str | java.lang.String, /) -> None: ...
    def setWriter(self, writer: java.io.Writer, /) -> None: ...

class StreamSource(javax.xml.transform.Source):
    FEATURE: typing.ClassVar[str] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, f: java.io.File, /) -> None: ...
    @typing.overload
    def __init__(self, inputStream: java.io.InputStream, /) -> None: ...
    @typing.overload
    def __init__(self, reader: java.io.Reader, /) -> None: ...
    @typing.overload
    def __init__(self, systemId: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, inputStream: java.io.InputStream, systemId: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, reader: java.io.Reader, systemId: str | java.lang.String, /) -> None: ...
    def getInputStream(self) -> java.io.InputStream: ...
    def getPublicId(self) -> str: ...
    def getReader(self) -> java.io.Reader: ...
    def getSystemId(self) -> str: ...
    def setInputStream(self, inputStream: java.io.InputStream, /) -> None: ...
    def setPublicId(self, publicId: str | java.lang.String, /) -> None: ...
    def setReader(self, reader: java.io.Reader, /) -> None: ...
    @typing.overload
    def setSystemId(self, f: java.io.File, /) -> None: ...
    @typing.overload
    def setSystemId(self, systemId: str | java.lang.String, /) -> None: ...



import typing

import android.graphics
import android.os
import android.view
import java
import java.chaquopy
import java.lang
import java.nio.channels
import java.time
import java.util

class BatteryState(java.lang.Object):
    STATUS_CHARGING: typing.ClassVar[int] = ...
    STATUS_DISCHARGING: typing.ClassVar[int] = ...
    STATUS_FULL: typing.ClassVar[int] = ...
    STATUS_NOT_CHARGING: typing.ClassVar[int] = ...
    STATUS_UNKNOWN: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    def getCapacity(self) -> float: ...
    def getStatus(self) -> int: ...
    def isPresent(self) -> bool: ...

class Camera(java.lang.Object):
    ACTION_NEW_PICTURE: typing.ClassVar[str] = ...
    ACTION_NEW_VIDEO: typing.ClassVar[str] = ...
    CAMERA_ERROR_EVICTED: typing.ClassVar[int] = ...
    CAMERA_ERROR_SERVER_DIED: typing.ClassVar[int] = ...
    CAMERA_ERROR_UNKNOWN: typing.ClassVar[int] = ...
    def addCallbackBuffer(self, callbackBuffer: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def autoFocus(self, cb: Camera.AutoFocusCallback, /) -> None: ...
    def cancelAutoFocus(self) -> None: ...
    def enableShutterSound(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def finalize(self) -> None: ...
    @staticmethod
    def getCameraInfo(cameraId: int | java.jint | java.lang.Integer, cameraInfo: Camera.CameraInfo, /) -> None: ...
    @staticmethod
    def getNumberOfCameras() -> int: ...
    def getParameters(self) -> Camera.Parameters: ...
    def lock(self) -> None: ...
    @typing.overload
    @staticmethod
    def open() -> Camera | None: ...
    @typing.overload
    @staticmethod
    def open(cameraId: int | java.jint | java.lang.Integer, /) -> Camera | None: ...
    def reconnect(self) -> None: ...
    def release(self) -> None: ...
    def setAutoFocusMoveCallback(self, cb: Camera.AutoFocusMoveCallback, /) -> None: ...
    def setDisplayOrientation(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def setErrorCallback(self, cb: Camera.ErrorCallback, /) -> None: ...
    def setFaceDetectionListener(self, listener: Camera.FaceDetectionListener, /) -> None: ...
    def setOneShotPreviewCallback(self, cb: Camera.PreviewCallback, /) -> None: ...
    def setParameters(self, params: Camera.Parameters, /) -> None: ...
    def setPreviewCallback(self, cb: Camera.PreviewCallback, /) -> None: ...
    def setPreviewCallbackWithBuffer(self, cb: Camera.PreviewCallback, /) -> None: ...
    def setPreviewDisplay(self, holder: android.view.SurfaceHolder, /) -> None: ...
    def setPreviewTexture(self, arg1: android.graphics.SurfaceTexture, /) -> None: ...
    def setZoomChangeListener(self, listener: Camera.OnZoomChangeListener, /) -> None: ...
    def startFaceDetection(self) -> None: ...
    def startPreview(self) -> None: ...
    def startSmoothZoom(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    def stopFaceDetection(self) -> None: ...
    def stopPreview(self) -> None: ...
    def stopSmoothZoom(self) -> None: ...
    @typing.overload
    def takePicture(self, shutter: Camera.ShutterCallback, raw: Camera.PictureCallback, jpeg: Camera.PictureCallback, /) -> None: ...
    @typing.overload
    def takePicture(self, shutter: Camera.ShutterCallback, raw: Camera.PictureCallback, postview: Camera.PictureCallback, jpeg: Camera.PictureCallback, /) -> None: ...
    def unlock(self) -> None: ...

    class Size(java.lang.Object):
        height: int = ...
        width: int = ...
        def __init__(self, this_0: Camera, w: int | java.jint | java.lang.Integer, h: int | java.jint | java.lang.Integer, /) -> None: ...
        def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def hashCode(self) -> int: ...

    class ShutterCallback(java.lang.Object):
        def onShutter(self) -> None: ...

    class PreviewCallback(java.lang.Object):
        def onPreviewFrame(self, arg1: java.chaquopy.JavaArrayJByte, arg2: Camera, /) -> None: ...

    class PictureCallback(java.lang.Object):
        def onPictureTaken(self, arg1: java.chaquopy.JavaArrayJByte, arg2: Camera, /) -> None: ...

    class Parameters(java.lang.Object):
        ANTIBANDING_50HZ: typing.ClassVar[str] = ...
        ANTIBANDING_60HZ: typing.ClassVar[str] = ...
        ANTIBANDING_AUTO: typing.ClassVar[str] = ...
        ANTIBANDING_OFF: typing.ClassVar[str] = ...
        EFFECT_AQUA: typing.ClassVar[str] = ...
        EFFECT_BLACKBOARD: typing.ClassVar[str] = ...
        EFFECT_MONO: typing.ClassVar[str] = ...
        EFFECT_NEGATIVE: typing.ClassVar[str] = ...
        EFFECT_NONE: typing.ClassVar[str] = ...
        EFFECT_POSTERIZE: typing.ClassVar[str] = ...
        EFFECT_SEPIA: typing.ClassVar[str] = ...
        EFFECT_SOLARIZE: typing.ClassVar[str] = ...
        EFFECT_WHITEBOARD: typing.ClassVar[str] = ...
        FLASH_MODE_AUTO: typing.ClassVar[str] = ...
        FLASH_MODE_OFF: typing.ClassVar[str] = ...
        FLASH_MODE_ON: typing.ClassVar[str] = ...
        FLASH_MODE_RED_EYE: typing.ClassVar[str] = ...
        FLASH_MODE_TORCH: typing.ClassVar[str] = ...
        FOCUS_DISTANCE_FAR_INDEX: typing.ClassVar[int] = ...
        FOCUS_DISTANCE_NEAR_INDEX: typing.ClassVar[int] = ...
        FOCUS_DISTANCE_OPTIMAL_INDEX: typing.ClassVar[int] = ...
        FOCUS_MODE_AUTO: typing.ClassVar[str] = ...
        FOCUS_MODE_CONTINUOUS_PICTURE: typing.ClassVar[str] = ...
        FOCUS_MODE_CONTINUOUS_VIDEO: typing.ClassVar[str] = ...
        FOCUS_MODE_EDOF: typing.ClassVar[str] = ...
        FOCUS_MODE_FIXED: typing.ClassVar[str] = ...
        FOCUS_MODE_INFINITY: typing.ClassVar[str] = ...
        FOCUS_MODE_MACRO: typing.ClassVar[str] = ...
        PREVIEW_FPS_MAX_INDEX: typing.ClassVar[int] = ...
        PREVIEW_FPS_MIN_INDEX: typing.ClassVar[int] = ...
        SCENE_MODE_ACTION: typing.ClassVar[str] = ...
        SCENE_MODE_AUTO: typing.ClassVar[str] = ...
        SCENE_MODE_BARCODE: typing.ClassVar[str] = ...
        SCENE_MODE_BEACH: typing.ClassVar[str] = ...
        SCENE_MODE_CANDLELIGHT: typing.ClassVar[str] = ...
        SCENE_MODE_FIREWORKS: typing.ClassVar[str] = ...
        SCENE_MODE_HDR: typing.ClassVar[str] = ...
        SCENE_MODE_LANDSCAPE: typing.ClassVar[str] = ...
        SCENE_MODE_NIGHT: typing.ClassVar[str] = ...
        SCENE_MODE_NIGHT_PORTRAIT: typing.ClassVar[str] = ...
        SCENE_MODE_PARTY: typing.ClassVar[str] = ...
        SCENE_MODE_PORTRAIT: typing.ClassVar[str] = ...
        SCENE_MODE_SNOW: typing.ClassVar[str] = ...
        SCENE_MODE_SPORTS: typing.ClassVar[str] = ...
        SCENE_MODE_STEADYPHOTO: typing.ClassVar[str] = ...
        SCENE_MODE_SUNSET: typing.ClassVar[str] = ...
        SCENE_MODE_THEATRE: typing.ClassVar[str] = ...
        WHITE_BALANCE_AUTO: typing.ClassVar[str] = ...
        WHITE_BALANCE_CLOUDY_DAYLIGHT: typing.ClassVar[str] = ...
        WHITE_BALANCE_DAYLIGHT: typing.ClassVar[str] = ...
        WHITE_BALANCE_FLUORESCENT: typing.ClassVar[str] = ...
        WHITE_BALANCE_INCANDESCENT: typing.ClassVar[str] = ...
        WHITE_BALANCE_SHADE: typing.ClassVar[str] = ...
        WHITE_BALANCE_TWILIGHT: typing.ClassVar[str] = ...
        WHITE_BALANCE_WARM_FLUORESCENT: typing.ClassVar[str] = ...
        def flatten(self) -> str: ...
        def get(self, key: str | java.lang.String, /) -> str: ...
        def getAntibanding(self) -> str: ...
        def getAutoExposureLock(self) -> bool: ...
        def getAutoWhiteBalanceLock(self) -> bool: ...
        def getColorEffect(self) -> str: ...
        def getExposureCompensation(self) -> int: ...
        def getExposureCompensationStep(self) -> float: ...
        def getFlashMode(self) -> str: ...
        def getFocalLength(self) -> float: ...
        def getFocusAreas(self) -> java.util.List[Camera.Area]: ...
        def getFocusDistances(self, output: java.chaquopy.JavaArrayJFloat, /) -> None: ...
        def getFocusMode(self) -> str: ...
        def getHorizontalViewAngle(self) -> float: ...
        def getInt(self, key: str | java.lang.String, /) -> int: ...
        def getJpegQuality(self) -> int: ...
        def getJpegThumbnailQuality(self) -> int: ...
        def getJpegThumbnailSize(self) -> Camera.Size: ...
        def getMaxExposureCompensation(self) -> int: ...
        def getMaxNumDetectedFaces(self) -> int: ...
        def getMaxNumFocusAreas(self) -> int: ...
        def getMaxNumMeteringAreas(self) -> int: ...
        def getMaxZoom(self) -> int: ...
        def getMeteringAreas(self) -> java.util.List[Camera.Area]: ...
        def getMinExposureCompensation(self) -> int: ...
        def getPictureFormat(self) -> int: ...
        def getPictureSize(self) -> Camera.Size: ...
        def getPreferredPreviewSizeForVideo(self) -> Camera.Size: ...
        def getPreviewFormat(self) -> int: ...
        def getPreviewFpsRange(self, range: java.chaquopy.JavaArrayJInt, /) -> None: ...
        def getPreviewFrameRate(self) -> int: ...
        def getPreviewSize(self) -> Camera.Size: ...
        def getSceneMode(self) -> str: ...
        def getSupportedAntibanding(self) -> java.util.List[java.lang.String]: ...
        def getSupportedColorEffects(self) -> java.util.List[java.lang.String]: ...
        def getSupportedFlashModes(self) -> java.util.List[java.lang.String]: ...
        def getSupportedFocusModes(self) -> java.util.List[java.lang.String]: ...
        def getSupportedJpegThumbnailSizes(self) -> java.util.List[Camera.Size]: ...
        def getSupportedPictureFormats(self) -> java.util.List[java.lang.Integer]: ...
        def getSupportedPictureSizes(self) -> java.util.List[Camera.Size]: ...
        def getSupportedPreviewFormats(self) -> java.util.List[java.lang.Integer]: ...
        def getSupportedPreviewFpsRange(self) -> java.util.List[java.chaquopy.JavaArrayJInt]: ...
        def getSupportedPreviewFrameRates(self) -> java.util.List[java.lang.Integer]: ...
        def getSupportedPreviewSizes(self) -> java.util.List[Camera.Size]: ...
        def getSupportedSceneModes(self) -> java.util.List[java.lang.String]: ...
        def getSupportedVideoSizes(self) -> java.util.List[Camera.Size]: ...
        def getSupportedWhiteBalance(self) -> java.util.List[java.lang.String]: ...
        def getVerticalViewAngle(self) -> float: ...
        def getVideoStabilization(self) -> bool: ...
        def getWhiteBalance(self) -> str: ...
        def getZoom(self) -> int: ...
        def getZoomRatios(self) -> java.util.List[java.lang.Integer]: ...
        def isAutoExposureLockSupported(self) -> bool: ...
        def isAutoWhiteBalanceLockSupported(self) -> bool: ...
        def isSmoothZoomSupported(self) -> bool: ...
        def isVideoSnapshotSupported(self) -> bool: ...
        def isVideoStabilizationSupported(self) -> bool: ...
        def isZoomSupported(self) -> bool: ...
        def remove(self, key: str | java.lang.String, /) -> None: ...
        def removeGpsData(self) -> None: ...
        @typing.overload
        def set(self, key: str | java.lang.String, value: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def set(self, key: str | java.lang.String, value: str | java.lang.String, /) -> None: ...
        def setAntibanding(self, antibanding: str | java.lang.String, /) -> None: ...
        def setAutoExposureLock(self, toggle: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def setAutoWhiteBalanceLock(self, toggle: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def setColorEffect(self, value: str | java.lang.String, /) -> None: ...
        def setExposureCompensation(self, value: int | java.jint | java.lang.Integer, /) -> None: ...
        def setFlashMode(self, value: str | java.lang.String, /) -> None: ...
        def setFocusAreas(self, focusAreas: java.util.List[Camera.Area], /) -> None: ...
        def setFocusMode(self, value: str | java.lang.String, /) -> None: ...
        def setGpsAltitude(self, altitude: float | java.jdouble | java.lang.Double, /) -> None: ...
        def setGpsLatitude(self, latitude: float | java.jdouble | java.lang.Double, /) -> None: ...
        def setGpsLongitude(self, longitude: float | java.jdouble | java.lang.Double, /) -> None: ...
        def setGpsProcessingMethod(self, processing_method: str | java.lang.String, /) -> None: ...
        def setGpsTimestamp(self, timestamp: int | java.jlong | java.lang.Long, /) -> None: ...
        def setJpegQuality(self, quality: int | java.jint | java.lang.Integer, /) -> None: ...
        def setJpegThumbnailQuality(self, quality: int | java.jint | java.lang.Integer, /) -> None: ...
        def setJpegThumbnailSize(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> None: ...
        def setMeteringAreas(self, meteringAreas: java.util.List[Camera.Area], /) -> None: ...
        def setPictureFormat(self, pixel_format: int | java.jint | java.lang.Integer, /) -> None: ...
        def setPictureSize(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> None: ...
        def setPreviewFormat(self, pixel_format: int | java.jint | java.lang.Integer, /) -> None: ...
        def setPreviewFpsRange(self, min: int | java.jint | java.lang.Integer, max: int | java.jint | java.lang.Integer, /) -> None: ...
        def setPreviewFrameRate(self, fps: int | java.jint | java.lang.Integer, /) -> None: ...
        def setPreviewSize(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> None: ...
        def setRecordingHint(self, hint: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def setRotation(self, rotation: int | java.jint | java.lang.Integer, /) -> None: ...
        def setSceneMode(self, value: str | java.lang.String, /) -> None: ...
        def setVideoStabilization(self, toggle: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def setWhiteBalance(self, value: str | java.lang.String, /) -> None: ...
        def setZoom(self, value: int | java.jint | java.lang.Integer, /) -> None: ...
        def unflatten(self, flattened: str | java.lang.String, /) -> None: ...

    class OnZoomChangeListener(java.lang.Object):
        def onZoomChange(self, arg1: int | java.jint | java.lang.Integer, arg2: bool | java.jboolean | java.lang.Boolean, arg3: Camera, /) -> None: ...

    class FaceDetectionListener(java.lang.Object):
        def onFaceDetection(self, arg1: java.chaquopy.JavaArray[Camera.Face], arg2: Camera, /) -> None: ...

    class Face(java.lang.Object):
        id: int = ...
        leftEye: android.graphics.Point = ...
        mouth: android.graphics.Point = ...
        rect: android.graphics.Rect = ...
        rightEye: android.graphics.Point = ...
        score: int = ...
        def __init__(self) -> None: ...

    class ErrorCallback(java.lang.Object):
        def onError(self, arg1: int | java.jint | java.lang.Integer, arg2: Camera, /) -> None: ...

    class CameraInfo(java.lang.Object):
        CAMERA_FACING_BACK: typing.ClassVar[int] = ...
        CAMERA_FACING_FRONT: typing.ClassVar[int] = ...
        canDisableShutterSound: bool = ...
        facing: int = ...
        orientation: int = ...
        def __init__(self) -> None: ...

    class AutoFocusMoveCallback(java.lang.Object):
        def onAutoFocusMoving(self, arg1: bool | java.jboolean | java.lang.Boolean, arg2: Camera, /) -> None: ...

    class AutoFocusCallback(java.lang.Object):
        def onAutoFocus(self, arg1: bool | java.jboolean | java.lang.Boolean, arg2: Camera, /) -> None: ...

    class Area(java.lang.Object):
        rect: android.graphics.Rect = ...
        weight: int = ...
        def __init__(self, rect: android.graphics.Rect, weight: int | java.jint | java.lang.Integer, /) -> None: ...
        def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...

class ConsumerIrManager(java.lang.Object):
    def getCarrierFrequencies(self) -> java.chaquopy.JavaArray[ConsumerIrManager.CarrierFrequencyRange]: ...
    def hasIrEmitter(self) -> bool: ...
    def transmit(self, carrierFrequency: int | java.jint | java.lang.Integer, pattern: java.chaquopy.JavaArrayJInt, /) -> None: ...

    class CarrierFrequencyRange(java.lang.Object):
        def __init__(self, this_0: ConsumerIrManager, min: int | java.jint | java.lang.Integer, max: int | java.jint | java.lang.Integer, /) -> None: ...
        def getMaxFrequency(self) -> int: ...
        def getMinFrequency(self) -> int: ...

class DataSpace(java.lang.Object):
    DATASPACE_ADOBE_RGB: typing.ClassVar[int] = ...
    DATASPACE_BT2020: typing.ClassVar[int] = ...
    DATASPACE_BT2020_HLG: typing.ClassVar[int] = ...
    DATASPACE_BT2020_PQ: typing.ClassVar[int] = ...
    DATASPACE_BT601_525: typing.ClassVar[int] = ...
    DATASPACE_BT601_625: typing.ClassVar[int] = ...
    DATASPACE_BT709: typing.ClassVar[int] = ...
    DATASPACE_DCI_P3: typing.ClassVar[int] = ...
    DATASPACE_DEPTH: typing.ClassVar[int] = ...
    DATASPACE_DISPLAY_P3: typing.ClassVar[int] = ...
    DATASPACE_DYNAMIC_DEPTH: typing.ClassVar[int] = ...
    DATASPACE_HEIF: typing.ClassVar[int] = ...
    DATASPACE_HEIF_ULTRAHDR: typing.ClassVar[int] = ...
    DATASPACE_JFIF: typing.ClassVar[int] = ...
    DATASPACE_JPEG_R: typing.ClassVar[int] = ...
    DATASPACE_SCRGB: typing.ClassVar[int] = ...
    DATASPACE_SCRGB_LINEAR: typing.ClassVar[int] = ...
    DATASPACE_SRGB: typing.ClassVar[int] = ...
    DATASPACE_SRGB_LINEAR: typing.ClassVar[int] = ...
    DATASPACE_UNKNOWN: typing.ClassVar[int] = ...
    RANGE_EXTENDED: typing.ClassVar[int] = ...
    RANGE_FULL: typing.ClassVar[int] = ...
    RANGE_LIMITED: typing.ClassVar[int] = ...
    RANGE_UNSPECIFIED: typing.ClassVar[int] = ...
    STANDARD_ADOBE_RGB: typing.ClassVar[int] = ...
    STANDARD_BT2020: typing.ClassVar[int] = ...
    STANDARD_BT2020_CONSTANT_LUMINANCE: typing.ClassVar[int] = ...
    STANDARD_BT470M: typing.ClassVar[int] = ...
    STANDARD_BT601_525: typing.ClassVar[int] = ...
    STANDARD_BT601_525_UNADJUSTED: typing.ClassVar[int] = ...
    STANDARD_BT601_625: typing.ClassVar[int] = ...
    STANDARD_BT601_625_UNADJUSTED: typing.ClassVar[int] = ...
    STANDARD_BT709: typing.ClassVar[int] = ...
    STANDARD_DCI_P3: typing.ClassVar[int] = ...
    STANDARD_FILM: typing.ClassVar[int] = ...
    STANDARD_UNSPECIFIED: typing.ClassVar[int] = ...
    TRANSFER_GAMMA2_2: typing.ClassVar[int] = ...
    TRANSFER_GAMMA2_6: typing.ClassVar[int] = ...
    TRANSFER_GAMMA2_8: typing.ClassVar[int] = ...
    TRANSFER_HLG: typing.ClassVar[int] = ...
    TRANSFER_LINEAR: typing.ClassVar[int] = ...
    TRANSFER_SMPTE_170M: typing.ClassVar[int] = ...
    TRANSFER_SRGB: typing.ClassVar[int] = ...
    TRANSFER_ST2084: typing.ClassVar[int] = ...
    TRANSFER_UNSPECIFIED: typing.ClassVar[int] = ...
    @staticmethod
    def getRange(dataSpace: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def getStandard(dataSpace: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def getTransfer(dataSpace: int | java.jint | java.lang.Integer, /) -> int: ...
    @staticmethod
    def pack(standard: int | java.jint | java.lang.Integer, transfer: int | java.jint | java.lang.Integer, range: int | java.jint | java.lang.Integer, /) -> int: ...

class DisplayLuts(java.lang.Object):
    def __init__(self) -> None: ...
    @typing.overload
    def set(self, entry: DisplayLuts.Entry, /) -> None: ...
    @typing.overload
    def set(self, first: DisplayLuts.Entry, second: DisplayLuts.Entry, /) -> None: ...
    def toString(self) -> str: ...

    class Entry(java.lang.Object):
        def __init__(self, buffer: java.chaquopy.JavaArrayJFloat, dimension: int | java.jint | java.lang.Integer, samplingKey: int | java.jint | java.lang.Integer, /) -> None: ...
        def getBuffer(self) -> java.chaquopy.JavaArrayJFloat: ...
        def getDimension(self) -> int: ...
        def getSamplingKey(self) -> int: ...
        def toString(self) -> str: ...

class GeomagneticField(java.lang.Object):
    def __init__(self, gdLatitudeDeg: float | java.jfloat | java.lang.Float, gdLongitudeDeg: float | java.jfloat | java.lang.Float, altitudeMeters: float | java.jfloat | java.lang.Float, timeMillis: int | java.jlong | java.lang.Long, /) -> None: ...
    def getDeclination(self) -> float: ...
    def getFieldStrength(self) -> float: ...
    def getHorizontalStrength(self) -> float: ...
    def getInclination(self) -> float: ...
    def getX(self) -> float: ...
    def getY(self) -> float: ...
    def getZ(self) -> float: ...

class HardwareBuffer(android.os.Parcelable, java.lang.AutoCloseable):
    BLOB: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[HardwareBuffer]] = ...
    DS_24UI8: typing.ClassVar[int] = ...
    DS_FP32UI8: typing.ClassVar[int] = ...
    D_16: typing.ClassVar[int] = ...
    D_24: typing.ClassVar[int] = ...
    D_FP32: typing.ClassVar[int] = ...
    RGBA_10101010: typing.ClassVar[int] = ...
    RGBA_1010102: typing.ClassVar[int] = ...
    RGBA_8888: typing.ClassVar[int] = ...
    RGBA_FP16: typing.ClassVar[int] = ...
    RGBX_8888: typing.ClassVar[int] = ...
    RGB_565: typing.ClassVar[int] = ...
    RGB_888: typing.ClassVar[int] = ...
    RG_1616: typing.ClassVar[int] = ...
    R_16: typing.ClassVar[int] = ...
    R_8: typing.ClassVar[int] = ...
    S_UI8: typing.ClassVar[int] = ...
    USAGE_COMPOSER_OVERLAY: typing.ClassVar[int] = ...
    USAGE_CPU_READ_OFTEN: typing.ClassVar[int] = ...
    USAGE_CPU_READ_RARELY: typing.ClassVar[int] = ...
    USAGE_CPU_WRITE_OFTEN: typing.ClassVar[int] = ...
    USAGE_CPU_WRITE_RARELY: typing.ClassVar[int] = ...
    USAGE_FRONT_BUFFER: typing.ClassVar[int] = ...
    USAGE_GPU_COLOR_OUTPUT: typing.ClassVar[int] = ...
    USAGE_GPU_CUBE_MAP: typing.ClassVar[int] = ...
    USAGE_GPU_DATA_BUFFER: typing.ClassVar[int] = ...
    USAGE_GPU_MIPMAP_COMPLETE: typing.ClassVar[int] = ...
    USAGE_GPU_SAMPLED_IMAGE: typing.ClassVar[int] = ...
    USAGE_PROTECTED_CONTENT: typing.ClassVar[int] = ...
    USAGE_SENSOR_DIRECT_DATA: typing.ClassVar[int] = ...
    USAGE_VIDEO_ENCODE: typing.ClassVar[int] = ...
    YCBCR_420_888: typing.ClassVar[int] = ...
    YCBCR_P010: typing.ClassVar[int] = ...
    YCBCR_P210: typing.ClassVar[int] = ...
    def close(self) -> None: ...
    @staticmethod
    def create(width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, format: int | java.jint | java.lang.Integer, layers: int | java.jint | java.lang.Integer, usage: int | java.jlong | java.lang.Long, /) -> HardwareBuffer: ...
    def describeContents(self) -> int: ...
    def finalize(self) -> None: ...
    def getFormat(self) -> int: ...
    def getHeight(self) -> int: ...
    def getId(self) -> int: ...
    def getLayers(self) -> int: ...
    def getUsage(self) -> int: ...
    def getWidth(self) -> int: ...
    def isClosed(self) -> bool: ...
    @staticmethod
    def isSupported(width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, format: int | java.jint | java.lang.Integer, layers: int | java.jint | java.lang.Integer, usage: int | java.jlong | java.lang.Long, /) -> bool: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class LutProperties(java.lang.Object):
    ONE_DIMENSION: typing.ClassVar[int] = ...
    SAMPLING_KEY_CIE_Y: typing.ClassVar[int] = ...
    SAMPLING_KEY_MAX_RGB: typing.ClassVar[int] = ...
    SAMPLING_KEY_RGB: typing.ClassVar[int] = ...
    THREE_DIMENSION: typing.ClassVar[int] = ...
    def getDimension(self) -> int: ...
    def getSamplingKeys(self) -> java.chaquopy.JavaArrayJInt: ...
    def getSize(self) -> int: ...

class OverlayProperties(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[OverlayProperties]] = ...
    def describeContents(self) -> int: ...
    def getLutProperties(self) -> java.chaquopy.JavaArray[LutProperties]: ...
    def isCombinationSupported(self, dataspace: int | java.jint | java.lang.Integer, format: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isMixedColorSpacesSupported(self) -> bool: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class Sensor(java.lang.Object):
    REPORTING_MODE_CONTINUOUS: typing.ClassVar[int] = ...
    REPORTING_MODE_ONE_SHOT: typing.ClassVar[int] = ...
    REPORTING_MODE_ON_CHANGE: typing.ClassVar[int] = ...
    REPORTING_MODE_SPECIAL_TRIGGER: typing.ClassVar[int] = ...
    STRING_TYPE_ACCELEROMETER: typing.ClassVar[str] = ...
    STRING_TYPE_ACCELEROMETER_LIMITED_AXES: typing.ClassVar[str] = ...
    STRING_TYPE_ACCELEROMETER_LIMITED_AXES_UNCALIBRATED: typing.ClassVar[str] = ...
    STRING_TYPE_ACCELEROMETER_UNCALIBRATED: typing.ClassVar[str] = ...
    STRING_TYPE_AMBIENT_TEMPERATURE: typing.ClassVar[str] = ...
    STRING_TYPE_GAME_ROTATION_VECTOR: typing.ClassVar[str] = ...
    STRING_TYPE_GEOMAGNETIC_ROTATION_VECTOR: typing.ClassVar[str] = ...
    STRING_TYPE_GRAVITY: typing.ClassVar[str] = ...
    STRING_TYPE_GYROSCOPE: typing.ClassVar[str] = ...
    STRING_TYPE_GYROSCOPE_LIMITED_AXES: typing.ClassVar[str] = ...
    STRING_TYPE_GYROSCOPE_LIMITED_AXES_UNCALIBRATED: typing.ClassVar[str] = ...
    STRING_TYPE_GYROSCOPE_UNCALIBRATED: typing.ClassVar[str] = ...
    STRING_TYPE_HEADING: typing.ClassVar[str] = ...
    STRING_TYPE_HEAD_TRACKER: typing.ClassVar[str] = ...
    STRING_TYPE_HEART_BEAT: typing.ClassVar[str] = ...
    STRING_TYPE_HEART_RATE: typing.ClassVar[str] = ...
    STRING_TYPE_HINGE_ANGLE: typing.ClassVar[str] = ...
    STRING_TYPE_LIGHT: typing.ClassVar[str] = ...
    STRING_TYPE_LINEAR_ACCELERATION: typing.ClassVar[str] = ...
    STRING_TYPE_LOW_LATENCY_OFFBODY_DETECT: typing.ClassVar[str] = ...
    STRING_TYPE_MAGNETIC_FIELD: typing.ClassVar[str] = ...
    STRING_TYPE_MAGNETIC_FIELD_UNCALIBRATED: typing.ClassVar[str] = ...
    STRING_TYPE_MOTION_DETECT: typing.ClassVar[str] = ...
    STRING_TYPE_ORIENTATION: typing.ClassVar[str] = ...
    STRING_TYPE_POSE_6DOF: typing.ClassVar[str] = ...
    STRING_TYPE_PRESSURE: typing.ClassVar[str] = ...
    STRING_TYPE_PROXIMITY: typing.ClassVar[str] = ...
    STRING_TYPE_RELATIVE_HUMIDITY: typing.ClassVar[str] = ...
    STRING_TYPE_ROTATION_VECTOR: typing.ClassVar[str] = ...
    STRING_TYPE_SIGNIFICANT_MOTION: typing.ClassVar[str] = ...
    STRING_TYPE_STATIONARY_DETECT: typing.ClassVar[str] = ...
    STRING_TYPE_STEP_COUNTER: typing.ClassVar[str] = ...
    STRING_TYPE_STEP_DETECTOR: typing.ClassVar[str] = ...
    STRING_TYPE_TEMPERATURE: typing.ClassVar[str] = ...
    TYPE_ACCELEROMETER: typing.ClassVar[int] = ...
    TYPE_ACCELEROMETER_LIMITED_AXES: typing.ClassVar[int] = ...
    TYPE_ACCELEROMETER_LIMITED_AXES_UNCALIBRATED: typing.ClassVar[int] = ...
    TYPE_ACCELEROMETER_UNCALIBRATED: typing.ClassVar[int] = ...
    TYPE_ALL: typing.ClassVar[int] = ...
    TYPE_AMBIENT_TEMPERATURE: typing.ClassVar[int] = ...
    TYPE_DEVICE_PRIVATE_BASE: typing.ClassVar[int] = ...
    TYPE_GAME_ROTATION_VECTOR: typing.ClassVar[int] = ...
    TYPE_GEOMAGNETIC_ROTATION_VECTOR: typing.ClassVar[int] = ...
    TYPE_GRAVITY: typing.ClassVar[int] = ...
    TYPE_GYROSCOPE: typing.ClassVar[int] = ...
    TYPE_GYROSCOPE_LIMITED_AXES: typing.ClassVar[int] = ...
    TYPE_GYROSCOPE_LIMITED_AXES_UNCALIBRATED: typing.ClassVar[int] = ...
    TYPE_GYROSCOPE_UNCALIBRATED: typing.ClassVar[int] = ...
    TYPE_HEADING: typing.ClassVar[int] = ...
    TYPE_HEAD_TRACKER: typing.ClassVar[int] = ...
    TYPE_HEART_BEAT: typing.ClassVar[int] = ...
    TYPE_HEART_RATE: typing.ClassVar[int] = ...
    TYPE_HINGE_ANGLE: typing.ClassVar[int] = ...
    TYPE_LIGHT: typing.ClassVar[int] = ...
    TYPE_LINEAR_ACCELERATION: typing.ClassVar[int] = ...
    TYPE_LOW_LATENCY_OFFBODY_DETECT: typing.ClassVar[int] = ...
    TYPE_MAGNETIC_FIELD: typing.ClassVar[int] = ...
    TYPE_MAGNETIC_FIELD_UNCALIBRATED: typing.ClassVar[int] = ...
    TYPE_MOTION_DETECT: typing.ClassVar[int] = ...
    TYPE_ORIENTATION: typing.ClassVar[int] = ...
    TYPE_POSE_6DOF: typing.ClassVar[int] = ...
    TYPE_PRESSURE: typing.ClassVar[int] = ...
    TYPE_PROXIMITY: typing.ClassVar[int] = ...
    TYPE_RELATIVE_HUMIDITY: typing.ClassVar[int] = ...
    TYPE_ROTATION_VECTOR: typing.ClassVar[int] = ...
    TYPE_SIGNIFICANT_MOTION: typing.ClassVar[int] = ...
    TYPE_STATIONARY_DETECT: typing.ClassVar[int] = ...
    TYPE_STEP_COUNTER: typing.ClassVar[int] = ...
    TYPE_STEP_DETECTOR: typing.ClassVar[int] = ...
    TYPE_TEMPERATURE: typing.ClassVar[int] = ...
    def getFifoMaxEventCount(self) -> int: ...
    def getFifoReservedEventCount(self) -> int: ...
    def getHighestDirectReportRateLevel(self) -> int: ...
    def getId(self) -> int: ...
    def getMaxDelay(self) -> int: ...
    def getMaximumRange(self) -> float: ...
    def getMinDelay(self) -> int: ...
    def getName(self) -> str: ...
    def getPower(self) -> float: ...
    def getReportingMode(self) -> int: ...
    def getResolution(self) -> float: ...
    def getStringType(self) -> str: ...
    def getType(self) -> int: ...
    def getVendor(self) -> str: ...
    def getVersion(self) -> int: ...
    def isAdditionalInfoSupported(self) -> bool: ...
    def isDirectChannelTypeSupported(self, sharedMemType: int | java.jint | java.lang.Integer, /) -> bool: ...
    def isDynamicSensor(self) -> bool: ...
    def isWakeUpSensor(self) -> bool: ...
    def toString(self) -> str: ...

class SensorAdditionalInfo(java.lang.Object):
    TYPE_FRAME_BEGIN: typing.ClassVar[int] = ...
    TYPE_FRAME_END: typing.ClassVar[int] = ...
    TYPE_INTERNAL_TEMPERATURE: typing.ClassVar[int] = ...
    TYPE_SAMPLING: typing.ClassVar[int] = ...
    TYPE_SENSOR_PLACEMENT: typing.ClassVar[int] = ...
    TYPE_UNTRACKED_DELAY: typing.ClassVar[int] = ...
    TYPE_VEC3_CALIBRATION: typing.ClassVar[int] = ...
    floatValues: java.chaquopy.JavaArrayJFloat = ...
    intValues: java.chaquopy.JavaArrayJInt = ...
    sensor: Sensor = ...
    serial: int = ...
    type: int = ...

class SensorDirectChannel(java.nio.channels.Channel):
    RATE_FAST: typing.ClassVar[int] = ...
    RATE_NORMAL: typing.ClassVar[int] = ...
    RATE_STOP: typing.ClassVar[int] = ...
    RATE_VERY_FAST: typing.ClassVar[int] = ...
    TYPE_HARDWARE_BUFFER: typing.ClassVar[int] = ...
    TYPE_MEMORY_FILE: typing.ClassVar[int] = ...
    def close(self) -> None: ...
    def configure(self, sensor: Sensor, rateLevel: int | java.jint | java.lang.Integer, /) -> int: ...
    def finalize(self) -> None: ...
    def isOpen(self) -> bool: ...

class SensorEvent(java.lang.Object):
    accuracy: int = ...
    firstEventAfterDiscontinuity: bool = ...
    sensor: Sensor = ...
    timestamp: int = ...
    values: java.chaquopy.JavaArrayJFloat = ...

class SensorEventCallback(SensorEventListener2):
    def __init__(self) -> None: ...
    def onAccuracyChanged(self, sensor: Sensor, accuracy: int | java.jint | java.lang.Integer, /) -> None: ...
    def onFlushCompleted(self, sensor: Sensor, /) -> None: ...
    def onSensorAdditionalInfo(self, info: SensorAdditionalInfo, /) -> None: ...
    def onSensorChanged(self, event: SensorEvent, /) -> None: ...

class SensorEventListener(java.lang.Object):
    def onAccuracyChanged(self, arg1: Sensor, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def onSensorChanged(self, arg1: SensorEvent, /) -> None: ...

class SensorEventListener2(SensorEventListener):
    def onFlushCompleted(self, arg1: Sensor, /) -> None: ...

class SensorListener(java.lang.Object):
    def onAccuracyChanged(self, arg1: int | java.jint | java.lang.Integer, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    def onSensorChanged(self, arg1: int | java.jint | java.lang.Integer, arg2: java.chaquopy.JavaArrayJFloat, /) -> None: ...

class SensorManager(java.lang.Object):
    AXIS_MINUS_X: typing.ClassVar[int] = ...
    AXIS_MINUS_Y: typing.ClassVar[int] = ...
    AXIS_MINUS_Z: typing.ClassVar[int] = ...
    AXIS_X: typing.ClassVar[int] = ...
    AXIS_Y: typing.ClassVar[int] = ...
    AXIS_Z: typing.ClassVar[int] = ...
    DATA_X: typing.ClassVar[int] = ...
    DATA_Y: typing.ClassVar[int] = ...
    DATA_Z: typing.ClassVar[int] = ...
    GRAVITY_DEATH_STAR_I: typing.ClassVar[float] = ...
    GRAVITY_EARTH: typing.ClassVar[float] = ...
    GRAVITY_JUPITER: typing.ClassVar[float] = ...
    GRAVITY_MARS: typing.ClassVar[float] = ...
    GRAVITY_MERCURY: typing.ClassVar[float] = ...
    GRAVITY_MOON: typing.ClassVar[float] = ...
    GRAVITY_NEPTUNE: typing.ClassVar[float] = ...
    GRAVITY_PLUTO: typing.ClassVar[float] = ...
    GRAVITY_SATURN: typing.ClassVar[float] = ...
    GRAVITY_SUN: typing.ClassVar[float] = ...
    GRAVITY_THE_ISLAND: typing.ClassVar[float] = ...
    GRAVITY_URANUS: typing.ClassVar[float] = ...
    GRAVITY_VENUS: typing.ClassVar[float] = ...
    LIGHT_CLOUDY: typing.ClassVar[float] = ...
    LIGHT_FULLMOON: typing.ClassVar[float] = ...
    LIGHT_NO_MOON: typing.ClassVar[float] = ...
    LIGHT_OVERCAST: typing.ClassVar[float] = ...
    LIGHT_SHADE: typing.ClassVar[float] = ...
    LIGHT_SUNLIGHT: typing.ClassVar[float] = ...
    LIGHT_SUNLIGHT_MAX: typing.ClassVar[float] = ...
    LIGHT_SUNRISE: typing.ClassVar[float] = ...
    MAGNETIC_FIELD_EARTH_MAX: typing.ClassVar[float] = ...
    MAGNETIC_FIELD_EARTH_MIN: typing.ClassVar[float] = ...
    PRESSURE_STANDARD_ATMOSPHERE: typing.ClassVar[float] = ...
    RAW_DATA_INDEX: typing.ClassVar[int] = ...
    RAW_DATA_X: typing.ClassVar[int] = ...
    RAW_DATA_Y: typing.ClassVar[int] = ...
    RAW_DATA_Z: typing.ClassVar[int] = ...
    SENSOR_ACCELEROMETER: typing.ClassVar[int] = ...
    SENSOR_ALL: typing.ClassVar[int] = ...
    SENSOR_DELAY_FASTEST: typing.ClassVar[int] = ...
    SENSOR_DELAY_GAME: typing.ClassVar[int] = ...
    SENSOR_DELAY_NORMAL: typing.ClassVar[int] = ...
    SENSOR_DELAY_UI: typing.ClassVar[int] = ...
    SENSOR_LIGHT: typing.ClassVar[int] = ...
    SENSOR_MAGNETIC_FIELD: typing.ClassVar[int] = ...
    SENSOR_MAX: typing.ClassVar[int] = ...
    SENSOR_MIN: typing.ClassVar[int] = ...
    SENSOR_ORIENTATION: typing.ClassVar[int] = ...
    SENSOR_ORIENTATION_RAW: typing.ClassVar[int] = ...
    SENSOR_PROXIMITY: typing.ClassVar[int] = ...
    SENSOR_STATUS_ACCURACY_HIGH: typing.ClassVar[int] = ...
    SENSOR_STATUS_ACCURACY_LOW: typing.ClassVar[int] = ...
    SENSOR_STATUS_ACCURACY_MEDIUM: typing.ClassVar[int] = ...
    SENSOR_STATUS_NO_CONTACT: typing.ClassVar[int] = ...
    SENSOR_STATUS_UNRELIABLE: typing.ClassVar[int] = ...
    SENSOR_TEMPERATURE: typing.ClassVar[int] = ...
    SENSOR_TRICORDER: typing.ClassVar[int] = ...
    STANDARD_GRAVITY: typing.ClassVar[float] = ...
    def cancelTriggerSensor(self, listener: TriggerEventListener, sensor: Sensor, /) -> bool: ...
    @typing.overload
    def createDirectChannel(self, mem: HardwareBuffer, /) -> SensorDirectChannel: ...
    @typing.overload
    def createDirectChannel(self, mem: android.os.MemoryFile, /) -> SensorDirectChannel: ...
    def flush(self, listener: SensorEventListener, /) -> bool: ...
    @staticmethod
    def getAltitude(p0: float | java.jfloat | java.lang.Float, p: float | java.jfloat | java.lang.Float, /) -> float: ...
    @staticmethod
    def getAngleChange(angleChange: java.chaquopy.JavaArrayJFloat, R: java.chaquopy.JavaArrayJFloat, prevR: java.chaquopy.JavaArrayJFloat, /) -> None: ...
    @typing.overload
    def getDefaultSensor(self, type: int | java.jint | java.lang.Integer, /) -> Sensor | None: ...
    @typing.overload
    def getDefaultSensor(self, type: int | java.jint | java.lang.Integer, wakeUp: bool | java.jboolean | java.lang.Boolean, /) -> Sensor | None: ...
    def getDynamicSensorList(self, type: int | java.jint | java.lang.Integer, /) -> java.util.List[Sensor]: ...
    @staticmethod
    def getInclination(I: java.chaquopy.JavaArrayJFloat, /) -> float: ...
    @staticmethod
    def getOrientation(R: java.chaquopy.JavaArrayJFloat, values: java.chaquopy.JavaArrayJFloat, /) -> java.chaquopy.JavaArrayJFloat: ...
    @staticmethod
    def getQuaternionFromVector(Q: java.chaquopy.JavaArrayJFloat, rv: java.chaquopy.JavaArrayJFloat, /) -> None: ...
    @staticmethod
    def getRotationMatrix(R: java.chaquopy.JavaArrayJFloat, I: java.chaquopy.JavaArrayJFloat, gravity: java.chaquopy.JavaArrayJFloat, geomagnetic: java.chaquopy.JavaArrayJFloat, /) -> bool: ...
    @staticmethod
    def getRotationMatrixFromVector(R: java.chaquopy.JavaArrayJFloat, rotationVector: java.chaquopy.JavaArrayJFloat, /) -> None: ...
    def getSensorList(self, type: int | java.jint | java.lang.Integer, /) -> java.util.List[Sensor]: ...
    def getSensors(self) -> int: ...
    def isDynamicSensorDiscoverySupported(self) -> bool: ...
    @typing.overload
    def registerDynamicSensorCallback(self, callback: SensorManager.DynamicSensorCallback, /) -> None: ...
    @typing.overload
    def registerDynamicSensorCallback(self, callback: SensorManager.DynamicSensorCallback, handler: android.os.Handler, /) -> None: ...
    @typing.overload
    def registerListener(self, listener: SensorListener, sensors: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    def registerListener(self, listener: SensorEventListener, sensor: Sensor, samplingPeriodUs: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    def registerListener(self, listener: SensorListener, sensors: int | java.jint | java.lang.Integer, rate: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    def registerListener(self, listener: SensorEventListener, sensor: Sensor, samplingPeriodUs: int | java.jint | java.lang.Integer, maxReportLatencyUs: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    def registerListener(self, listener: SensorEventListener, sensor: Sensor, samplingPeriodUs: int | java.jint | java.lang.Integer, handler: android.os.Handler, /) -> bool: ...
    @typing.overload
    def registerListener(self, listener: SensorEventListener, sensor: Sensor, samplingPeriodUs: int | java.jint | java.lang.Integer, maxReportLatencyUs: int | java.jint | java.lang.Integer, handler: android.os.Handler, /) -> bool: ...
    @staticmethod
    def remapCoordinateSystem(inR: java.chaquopy.JavaArrayJFloat, X: int | java.jint | java.lang.Integer, Y: int | java.jint | java.lang.Integer, outR: java.chaquopy.JavaArrayJFloat, /) -> bool: ...
    def requestTriggerSensor(self, listener: TriggerEventListener, sensor: Sensor, /) -> bool: ...
    def unregisterDynamicSensorCallback(self, callback: SensorManager.DynamicSensorCallback, /) -> None: ...
    @typing.overload
    def unregisterListener(self, listener: SensorEventListener, /) -> None: ...
    @typing.overload
    def unregisterListener(self, listener: SensorListener, /) -> None: ...
    @typing.overload
    def unregisterListener(self, listener: SensorEventListener, sensor: Sensor, /) -> None: ...
    @typing.overload
    def unregisterListener(self, listener: SensorListener, sensors: int | java.jint | java.lang.Integer, /) -> None: ...

    class DynamicSensorCallback(java.lang.Object):
        def __init__(self) -> None: ...
        def onDynamicSensorConnected(self, sensor: Sensor, /) -> None: ...
        def onDynamicSensorDisconnected(self, sensor: Sensor, /) -> None: ...

class SensorPrivacyManager(java.lang.Object):
    TOGGLE_TYPE_HARDWARE: typing.ClassVar[int] = ...
    TOGGLE_TYPE_SOFTWARE: typing.ClassVar[int] = ...
    @typing.overload
    def supportsSensorToggle(self, sensor: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    def supportsSensorToggle(self, toggleType: int | java.jint | java.lang.Integer, sensor: int | java.jint | java.lang.Integer, /) -> bool: ...

    class Sensors(java.lang.Object):
        CAMERA: typing.ClassVar[int] = ...
        MICROPHONE: typing.ClassVar[int] = ...

class SyncFence(android.os.Parcelable, java.lang.AutoCloseable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SyncFence]] = ...
    SIGNAL_TIME_INVALID: typing.ClassVar[int] = ...
    SIGNAL_TIME_PENDING: typing.ClassVar[int] = ...
    def __init__(self, other: SyncFence, /) -> None: ...
    def awaitForever(self) -> bool: ...
    def await_(self, timeout: java.time.Duration, /) -> bool: ...
    def close(self) -> None: ...
    def describeContents(self) -> int: ...
    def getSignalTime(self) -> int: ...
    def isValid(self) -> bool: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class TriggerEvent(java.lang.Object):
    sensor: Sensor = ...
    timestamp: int = ...
    values: java.chaquopy.JavaArrayJFloat = ...

class TriggerEventListener(java.lang.Object):
    def __init__(self) -> None: ...
    def onTrigger(self, arg1: TriggerEvent, /) -> None: ...



import typing

import java
import java.chaquopy
import java.io
import java.lang
import java.util.function
import java.util.stream

class MatchResult(java.lang.Object):
    @typing.overload
    def end(self) -> int: ...
    @typing.overload
    def end(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def group(self) -> str: ...
    @typing.overload
    def group(self, arg1: int | java.jint | java.lang.Integer, /) -> str | None: ...
    def groupCount(self) -> int: ...
    @typing.overload
    def start(self) -> int: ...
    @typing.overload
    def start(self, arg1: int | java.jint | java.lang.Integer, /) -> int: ...

class Matcher(MatchResult):
    @typing.overload
    def appendReplacement(self, sb: java.lang.StringBuffer, replacement: str | java.lang.String, /) -> Matcher: ...
    @typing.overload
    def appendReplacement(self, sb: java.lang.StringBuilder, replacement: str | java.lang.String, /) -> Matcher: ...
    @typing.overload
    def appendTail(self, sb: java.lang.StringBuffer, /) -> java.lang.StringBuffer: ...
    @typing.overload
    def appendTail(self, sb: java.lang.StringBuilder, /) -> java.lang.StringBuilder: ...
    @typing.overload
    def end(self) -> int: ...
    @typing.overload
    def end(self, group: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def end(self, name: str | java.lang.String, /) -> int: ...
    @typing.overload
    def find(self) -> bool: ...
    @typing.overload
    def find(self, start: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    def group(self) -> str | None: ...
    @typing.overload
    def group(self, group: int | java.jint | java.lang.Integer, /) -> str | None: ...
    @typing.overload
    def group(self, name: str | java.lang.String, /) -> str | None: ...
    def groupCount(self) -> int: ...
    def hasAnchoringBounds(self) -> bool: ...
    def hasTransparentBounds(self) -> bool: ...
    def hitEnd(self) -> bool: ...
    def lookingAt(self) -> bool: ...
    def matches(self) -> bool: ...
    def pattern(self) -> Pattern: ...
    @staticmethod
    def quoteReplacement(s: str | java.lang.String, /) -> str: ...
    def region(self, start: int | java.jint | java.lang.Integer, end: int | java.jint | java.lang.Integer, /) -> Matcher: ...
    def regionEnd(self) -> int: ...
    def regionStart(self) -> int: ...
    @typing.overload
    def replaceAll(self, replacement: str | java.lang.String, /) -> str: ...
    @typing.overload
    def replaceAll(self, replacer: java.util.function.Function[MatchResult, java.lang.String], /) -> str: ...
    @typing.overload
    def replaceFirst(self, replacement: str | java.lang.String, /) -> str: ...
    @typing.overload
    def replaceFirst(self, replacer: java.util.function.Function[MatchResult, java.lang.String], /) -> str: ...
    def requireEnd(self) -> bool: ...
    @typing.overload
    def reset(self) -> Matcher: ...
    @typing.overload
    def reset(self, input: java.lang.CharSequence, /) -> Matcher: ...
    def results(self) -> java.util.stream.Stream[MatchResult]: ...
    @typing.overload
    def start(self) -> int: ...
    @typing.overload
    def start(self, group: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def start(self, name: str | java.lang.String, /) -> int: ...
    def toMatchResult(self) -> MatchResult: ...
    def toString(self) -> str: ...
    def useAnchoringBounds(self, b: bool | java.jboolean | java.lang.Boolean, /) -> Matcher: ...
    def usePattern(self, newPattern: Pattern, /) -> Matcher: ...
    def useTransparentBounds(self, b: bool | java.jboolean | java.lang.Boolean, /) -> Matcher: ...

class Pattern(java.io.Serializable):
    CANON_EQ: typing.ClassVar[int] = ...
    CASE_INSENSITIVE: typing.ClassVar[int] = ...
    COMMENTS: typing.ClassVar[int] = ...
    DOTALL: typing.ClassVar[int] = ...
    LITERAL: typing.ClassVar[int] = ...
    MULTILINE: typing.ClassVar[int] = ...
    UNICODE_CASE: typing.ClassVar[int] = ...
    UNICODE_CHARACTER_CLASS: typing.ClassVar[int] = ...
    UNIX_LINES: typing.ClassVar[int] = ...
    def asMatchPredicate(self) -> java.util.function.Predicate[java.lang.String]: ...
    def asPredicate(self) -> java.util.function.Predicate[java.lang.String]: ...
    @typing.overload
    @staticmethod
    def compile(regex: str | java.lang.String, /) -> Pattern: ...
    @typing.overload
    @staticmethod
    def compile(regex: str | java.lang.String, flags: int | java.jint | java.lang.Integer, /) -> Pattern: ...
    def flags(self) -> int: ...
    def matcher(self, input: java.lang.CharSequence, /) -> Matcher: ...
    @staticmethod
    def matches(regex: str | java.lang.String, input: java.lang.CharSequence, /) -> bool: ...
    def pattern(self) -> str: ...
    @staticmethod
    def quote(s: str | java.lang.String, /) -> str: ...
    @typing.overload
    def split(self, input: java.lang.CharSequence, /) -> java.chaquopy.JavaArray[java.lang.String]: ...
    @typing.overload
    def split(self, input: java.lang.CharSequence, limit: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def splitAsStream(self, input: java.lang.CharSequence, /) -> java.util.stream.Stream[java.lang.String]: ...
    def toString(self) -> str: ...

class PatternSyntaxException(java.lang.IllegalArgumentException):
    def __init__(self, desc: str | java.lang.String, regex: str | java.lang.String, index: int | java.jint | java.lang.Integer, /) -> None: ...
    def getDescription(self) -> str: ...
    def getIndex(self) -> int: ...
    def getMessage(self) -> str: ...
    def getPattern(self) -> str: ...
